@@ -48,6 +48,7 @@ class GUI_EXPORT Qgs25DRendererWidget : public QgsRendererWidget, protected Ui::
      * \param renderer the mask renderer (will not take ownership)
      */
     Qgs25DRendererWidget( QgsVectorLayer *layer, QgsStyle *style, QgsFeatureRenderer *renderer SIP_TRANSFER );
+    ~Qgs25DRendererWidget() override;
 
     QgsFeatureRenderer *renderer() override;
 
@@ -57,7 +58,7 @@ class GUI_EXPORT Qgs25DRendererWidget : public QgsRendererWidget, protected Ui::
   private:
     void apply() override SIP_FORCE;
 
-    Qgs25DRenderer *mRenderer = nullptr;
+    std::unique_ptr< Qgs25DRenderer > mRenderer;
 
     friend class QgsAppScreenShots;
 };
