@@ -27,10 +27,9 @@ class QgsPanelWidget;
 /**
  * \ingroup gui
  * \class QgsColorButton
- * A cross platform button subclass for selecting colors. Will open a color chooser dialog when clicked.
+ * \brief A cross platform button subclass for selecting colors. Will open a color chooser dialog when clicked.
  * Offers live updates to button from color chooser dialog. An attached drop-down menu allows for copying
  * and pasting colors, picking colors from the screen, and selecting colors from color swatch grids.
- * \since QGIS 2.5
  */
 class GUI_EXPORT QgsColorButton : public QToolButton
 {
@@ -92,7 +91,6 @@ class GUI_EXPORT QgsColorButton : public QToolButton
      * for the color. Defaults to FALSE.
      * \param allowOpacity set to TRUE to allow opacity modification
      * \see allowOpacity()
-     * \since QGIS 3.0
      */
     void setAllowOpacity( bool allowOpacity );
 
@@ -101,7 +99,6 @@ class GUI_EXPORT QgsColorButton : public QToolButton
      * for the color.
      * \returns TRUE if opacity modification is allowed
      * \see setAllowOpacity()
-     * \since QGIS 3.0
      */
     bool allowOpacity() const { return mAllowOpacity; }
 
@@ -202,17 +199,16 @@ class GUI_EXPORT QgsColorButton : public QToolButton
     /**
      * Sets whether a set to null (clear) option is shown in the button's drop-down menu.
      * \param showNull set to TRUE to show a null option
+     * \param nullString translated string to use for the null option. If not set, a default "Clear Color" string will be used.
      * \see showNull()
      * \see isNull()
-     * \since QGIS 2.16
      */
-    void setShowNull( bool showNull );
+    void setShowNull( bool showNull, const QString &nullString = QString() );
 
     /**
      * Returns whether the set to null (clear) option is shown in the button's drop-down menu.
      * \see setShowNull()
      * \see isNull()
-     * \since QGIS 2.16
      */
     bool showNull() const;
 
@@ -220,7 +216,6 @@ class GUI_EXPORT QgsColorButton : public QToolButton
      * Returns TRUE if the current color is null.
      * \see setShowNull()
      * \see showNull()
-     * \since QGIS 2.16
      */
     bool isNull() const;
 
@@ -363,7 +358,6 @@ class GUI_EXPORT QgsColorButton : public QToolButton
      * \see setToDefaultColor()
      * \see setToNoColor()
      * \see cleared()
-     * \since QGIS 2.16
      */
     void setToNull();
 
@@ -460,6 +454,8 @@ class GUI_EXPORT QgsColorButton : public QToolButton
      */
     void dropEvent( QDropEvent *e ) override;
 
+    void wheelEvent( QWheelEvent *event ) override;
+
   private:
 
     Behavior mBehavior = QgsColorButton::ShowDialog;
@@ -481,6 +477,7 @@ class GUI_EXPORT QgsColorButton : public QToolButton
     bool mShowNoColorOption = false;
     QString mNoColorString;
     bool mShowNull = false;
+    QString mNullColorString;
 
     QPoint mDragStartPosition;
     bool mPickingColor = false;
