@@ -9,29 +9,27 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.36.0-Maidenhead"
-#define _QGIS_VERSION "3.36.0-Maidenhead"
+#define VERSION "3.38.3-Grenoble"
+#define _QGIS_VERSION "3.38.3-Grenoble"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3360
+//#define VERSION_INT 3383
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 33600
-#define _QGIS_VERSION_INT 33600
-#define ABISYM(x) x ## 33600
+#define VERSION_INT 33803
+#define _QGIS_VERSION_INT 33803
+#define ABISYM(x) x ## 33803
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Maidenhead"
+#define RELEASE_NAME "Grenoble"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
-#define CMAKE_INSTALL_PREFIX "/usr/local"
-#define CMAKE_SOURCE_DIR "/usr/obj/ports/qgis-3.36.0/qgis-3.36.0"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -44,15 +42,13 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define QT_PLUGINS_DIR "/usr/local/lib/qt5/plugins"
-
-#define PYTHON_VERSION "3.10.13"
+#define PYTHON_VERSION "3.11.10"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "10"
-#define PYTHON_VERSION_PATCH "13"
+#define PYTHON_VERSION_MINOR "11"
+#define PYTHON_VERSION_PATCH "10"
 
 #define PROJ_VERSION_MAJOR 9
-#define PROJ_VERSION_MINOR 4
+#define PROJ_VERSION_MINOR 5
 #define PROJ_VERSION_PATCH 0
 
 /* #undef USING_NMAKE */
@@ -107,12 +103,12 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.6.3"
+#define PDAL_VERSION "2.8.0"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 6
+#define PDAL_VERSION_MINOR_INT 8
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "6"
-#define PDAL_VERSION_MICRO "3"
+#define PDAL_VERSION_MINOR "8"
+#define PDAL_VERSION_MICRO "0"
 
 #define HAVE_DRACO
 
