@@ -21,6 +21,7 @@
 #include "qgis_core.h"
 #include "qgis_sip.h"
 #include "qgssurface.h"
+#include "qgscurve.h"
 #include <memory>
 
 class QgsPolygon;
@@ -29,7 +30,6 @@ class QgsPolygon;
  * \ingroup core
  * \class QgsCurvePolygon
  * \brief Curve polygon geometry type
- * \since QGIS 2.10
  */
 class CORE_EXPORT QgsCurvePolygon: public QgsSurface
 {
@@ -38,8 +38,80 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     QgsCurvePolygon( const QgsCurvePolygon &p );
     QgsCurvePolygon &operator=( const QgsCurvePolygon &p );
 
-    bool operator==( const QgsAbstractGeometry &other ) const override;
-    bool operator!=( const QgsAbstractGeometry &other ) const override;
+#ifndef SIP_RUN
+  private:
+    bool fuzzyHelper( const QgsAbstractGeometry &other, double epsilon, bool useDistance ) const
+    {
+      const QgsCurvePolygon *otherPolygon = qgsgeometry_cast< const QgsCurvePolygon * >( &other );
+      if ( !otherPolygon )
+        return false;
+
+      //run cheap checks first
+      if ( mWkbType != otherPolygon->mWkbType )
+        return false;
+
+      if ( ( !mExteriorRing && otherPolygon->mExteriorRing ) || ( mExteriorRing && !otherPolygon->mExteriorRing ) )
+        return false;
+
+      if ( mInteriorRings.count() != otherPolygon->mInteriorRings.count() )
+        return false;
+
+      // compare rings
+      if ( mExteriorRing && otherPolygon->mExteriorRing )
+      {
+        if ( useDistance )
+        {
+          if ( !( *mExteriorRing ).fuzzyDistanceEqual( *otherPolygon->mExteriorRing, epsilon ) )
+            return false;
+        }
+        else
+        {
+          if ( !( *mExteriorRing ).fuzzyEqual( *otherPolygon->mExteriorRing, epsilon ) )
+            return false;
+        }
+      }
+
+      for ( int i = 0; i < mInteriorRings.count(); ++i )
+      {
+        if ( ( !mInteriorRings.at( i ) && otherPolygon->mInteriorRings.at( i ) ) ||
+             ( mInteriorRings.at( i ) && !otherPolygon->mInteriorRings.at( i ) ) )
+          return false;
+
+        if ( useDistance )
+        {
+          if ( mInteriorRings.at( i ) && otherPolygon->mInteriorRings.at( i ) &&
+               !( *mInteriorRings.at( i ) ).fuzzyDistanceEqual( *otherPolygon->mInteriorRings.at( i ), epsilon ) )
+            return false;
+        }
+        else
+        {
+          if ( mInteriorRings.at( i ) && otherPolygon->mInteriorRings.at( i ) &&
+               !( *mInteriorRings.at( i ) ).fuzzyEqual( *otherPolygon->mInteriorRings.at( i ), epsilon ) )
+            return false;
+        }
+      }
+
+      return true;
+    }
+#endif
+  public:
+    bool fuzzyEqual( const QgsAbstractGeometry &other, double epsilon = 1e-8 ) const override SIP_HOLDGIL
+    {
+      return fuzzyHelper( other, epsilon, false );
+    }
+    bool fuzzyDistanceEqual( const QgsAbstractGeometry &other, double epsilon = 1e-8 ) const override SIP_HOLDGIL
+    {
+      return fuzzyHelper( other, epsilon, true );
+    }
+    bool operator==( const QgsAbstractGeometry &other ) const override
+    {
+      return fuzzyEqual( other, 1e-8 );
+    }
+
+    bool operator!=( const QgsAbstractGeometry &other ) const override
+    {
+      return !operator==( other );
+    }
 
     ~QgsCurvePolygon() override;
 
@@ -65,9 +137,10 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     double perimeter() const override SIP_HOLDGIL;
     QgsPolygon *surfaceToPolygon() const override SIP_FACTORY;
     QgsAbstractGeometry *boundary() const override SIP_FACTORY;
-    QgsCurvePolygon *snappedToGrid( double hSpacing, double vSpacing, double dSpacing = 0, double mSpacing = 0 ) const override SIP_FACTORY;
+    QgsCurvePolygon *snappedToGrid( double hSpacing, double vSpacing, double dSpacing = 0, double mSpacing = 0, bool removeRedundantPoints = false ) const override SIP_FACTORY;
+    QgsCurvePolygon *simplifyByDistance( double tolerance ) const override SIP_FACTORY;
     bool removeDuplicateNodes( double epsilon = 4 * std::numeric_limits<double>::epsilon(), bool useZValues = false ) override;
-    bool boundingBoxIntersects( const QgsRectangle &rectangle ) const override SIP_HOLDGIL;
+    bool boundingBoxIntersects( const QgsBox3D &box3d ) const override SIP_HOLDGIL;
 
     /**
      * Returns the roundness of the curve polygon.
@@ -230,7 +303,6 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
      * parameter is specified then only rings smaller than this minimum
      * area will be removed.
      * \see removeInteriorRing()
-     * \since QGIS 3.0
      */
     void removeInteriorRings( double minimumAllowedArea = -1 );
 
@@ -239,7 +311,6 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
      *
      * For example, this removes unclosed rings and rings with less than 4 vertices.
      *
-     * \since QGIS 3.0
      */
     void removeInvalidRings();
 
@@ -336,17 +407,16 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
      * Should be used by qgsgeometry_cast<QgsCurvePolygon *>( geometry ).
      *
      * \note Not available in Python. Objects will be automatically be converted to the appropriate target type.
-     * \since QGIS 3.0
      */
     inline static const QgsCurvePolygon *cast( const QgsAbstractGeometry *geom )
     {
       if ( !geom )
         return nullptr;
 
-      const QgsWkbTypes::Type flatType = QgsWkbTypes::flatType( geom->wkbType() );
-      if ( flatType == QgsWkbTypes::CurvePolygon
-           || flatType == QgsWkbTypes::Polygon
-           || flatType == QgsWkbTypes::Triangle )
+      const Qgis::WkbType flatType = QgsWkbTypes::flatType( geom->wkbType() );
+      if ( flatType == Qgis::WkbType::CurvePolygon
+           || flatType == Qgis::WkbType::Polygon
+           || flatType == Qgis::WkbType::Triangle )
         return static_cast<const QgsCurvePolygon *>( geom );
       return nullptr;
     }
@@ -376,7 +446,7 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     std::unique_ptr< QgsCurve > mExteriorRing;
     QVector<QgsCurve *> mInteriorRings;
 
-    QgsRectangle calculateBoundingBox() const override;
+    QgsBox3D calculateBoundingBox3D() const override;
 };
 
 // clazy:excludeall=qstring-allocations
