@@ -19,35 +19,39 @@
 
 #include "qgis_sip.h"
 #include "qgis_core.h"
-#include <QFileSystemWatcher>
+#include "qgsmimedatautils.h"
+#include "qgis.h"
+#include <QObject>
 #include <QFutureWatcher>
 #include <QIcon>
-#include <QObject>
-#include <QPixmap>
-#include <QString>
-#include <QTreeWidget>
-#include <QVector>
-#include <QDateTime>
 
-#include "qgsmaplayer.h"
-#include "qgscoordinatereferencesystem.h"
-#include "qgsmimedatautils.h"
-#include "qgswkbtypes.h"
-
-class QgsDataProvider;
 class QgsDataItem;
+class QMenu;
+class QgsAbstractDatabaseProviderConnection;
 class QgsAnimatedIcon;
-class QgsBookmarkManager;
+class QgsCoordinateReferenceSystem;
+
+class QAction;
+class QWidget;
 
 typedef QgsDataItem *dataItem_t( QString, QgsDataItem * ) SIP_SKIP;
 
 /**
  * \ingroup core
- * Base class for all items in the model.
+ * \brief Base class for all items in the model.
+ *
  * Parent/children hierarchy is not based on QObject.
 */
 class CORE_EXPORT QgsDataItem : public QObject
 {
+#ifdef SIP_RUN
+#include "qgslayeritem.h"
+#include "qgsdirectoryitem.h"
+#include "qgsfavoritesitem.h"
+#include "qgszipitem.h"
+#include "qgsdatacollectionitem.h"
+#include "qgsprojectitem.h"
+#endif
 
 #ifdef SIP_RUN
     SIP_CONVERT_TO_SUBCLASS_CODE
@@ -73,18 +77,6 @@ class CORE_EXPORT QgsDataItem : public QObject
     Q_OBJECT
 
   public:
-    enum Type
-    {
-      Collection,
-      Directory,
-      Layer,
-      Error,
-      Favorites, //!< Represents a favorite item
-      Project, //!< Represents a QGIS project
-      Custom, //!< Custom item type
-    };
-
-    Q_ENUM( Type )
 
     /**
      * Constructor for QgsDataItem, with the specified \a parent item.
@@ -97,10 +89,18 @@ class CORE_EXPORT QgsDataItem : public QObject
      *
      * The optional \a providerKey string (added in QGIS 3.12) can be used to specify the key for the QgsDataItemProvider that created this item.
      */
-    QgsDataItem( QgsDataItem::Type type, QgsDataItem *parent SIP_TRANSFERTHIS, const QString &name, const QString &path, const QString &providerKey = QString() );
+    QgsDataItem( Qgis::BrowserItemType type, QgsDataItem *parent SIP_TRANSFERTHIS, const QString &name, const QString &path, const QString &providerKey = QString() );
 
     ~QgsDataItem() override;
 
+#ifdef SIP_RUN
+    SIP_PYOBJECT __repr__();
+    % MethodCode
+    QString str = QStringLiteral( "<QgsDataItem: \"%1\" %2>" ).arg( sipCpp->name(), sipCpp->path() );
+    sipRes = PyUnicode_FromString( str.toUtf8().constData() );
+    % End
+#endif
+
     bool hasChildren();
 
     /**
@@ -114,26 +114,41 @@ class CORE_EXPORT QgsDataItem : public QObject
 
     /**
      * Create children. Children are not expected to have parent set.
-     * This method MUST BE THREAD SAFE. */
-    virtual QVector<QgsDataItem *> createChildren() SIP_FACTORY;
-
-    enum State
+     * \warning This method MUST BE THREAD SAFE.
+    */
+    virtual QVector<QgsDataItem *> createChildren() SIP_TRANSFERBACK;
+#ifdef SIP_RUN
+    SIP_VIRTUAL_CATCHER_CODE
+    PyObject *sipResObj = sipCallMethod( 0, sipMethod, "" );
+    // H = Convert a Python object to a mapped type instance.
+    // 5 = 1 (disallows the conversion of Py_None to NULL) + 4 (returns a copy of the C/C++ instance)
+    sipIsErr = !sipResObj || sipParseResult( 0, sipMethod, sipResObj, "H5", sipType_QVector_0101QgsDataItem, &sipRes ) < 0;
+    if ( !sipIsErr )
     {
-      NotPopulated, //!< Children not yet created
-      Populating,   //!< Creating children in separate thread (populating or refreshing)
-      Populated     //!< Children created
-    };
-    Q_ENUM( State )
+      for ( QgsDataItem *item : sipRes )
+      {
+        PyObject *pyItem = sipGetPyObject( item, sipType_QgsDataItem );
+        if ( pyItem != NULL )
+        {
+          // pyItem is given an extra reference which is removed when the C++ instance’s destructor is called.
+          sipTransferTo( pyItem, Py_None );
+        }
+      }
+    }
+    if ( sipResObj != NULL )
+    {
+      Py_DECREF( sipResObj );
+    }
+    SIP_END
+#endif
 
-    //! \since QGIS 2.8
-    State state() const;
+    Qgis::BrowserItemState state() const;
 
     /**
      * Set item state. It also take care about starting/stopping loading icon animation.
      * \param state
-     * \since QGIS 2.8
      */
-    virtual void setState( State state );
+    virtual void setState( Qgis::BrowserItemState state );
 
     /**
      * Inserts a new child item. The child will be inserted at a position using an alphabetical order based on mName.
@@ -186,7 +201,6 @@ class CORE_EXPORT QgsDataItem : public QObject
      * created menus is correctly handled by parenting them to the specified parent widget.
      * \param parent a parent widget of the menu
      * \returns list of menus
-     * \since QGIS 3.0
      */
     virtual QList<QMenu *> menus( QWidget *parent );
 
@@ -200,6 +214,11 @@ class CORE_EXPORT QgsDataItem : public QObject
      */
     Q_DECL_DEPRECATED virtual bool acceptDrop() SIP_DEPRECATED { return false; }
 
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Woverloaded-virtual"
+#endif
+
     /**
      * Attempts to process the mime data dropped on this item. Subclasses must override this and acceptDrop() if they
      * accept dropped layers.
@@ -209,21 +228,22 @@ class CORE_EXPORT QgsDataItem : public QObject
      * \deprecated QGIS 3.10
      */
     Q_DECL_DEPRECATED virtual bool handleDrop( const QMimeData * /*data*/, Qt::DropAction /*action*/ ) SIP_DEPRECATED { return false; }
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
 
     /**
      * Called when a user double clicks on the item. Subclasses should return TRUE
      * if they have implemented a double-click handler and do not want the default
      * double-click behavior for items.
-     * \since QGIS 3.0
      */
     virtual bool handleDoubleClick();
 
     /**
      * Returns TRUE if the item may be dragged.
      * Default implementation returns FALSE.
-     * A draggable item has to implement mimeUri() that will be used to pass data.
-     * \see mimeUri()
-     * \since QGIS 3.0
+     * A draggable item has to implement mimeUris() that will be used to pass data.
+     * \see mimeUris()
      */
     virtual bool hasDragEnabled() const { return false; }
 
@@ -231,21 +251,19 @@ class CORE_EXPORT QgsDataItem : public QObject
      * Returns mime URI for the data item.
      * Items that return valid URI will be returned in mime data when dragging a selection from browser model.
      * \see hasDragEnabled()
-     * \since QGIS 3.0
+     * \deprecated since QGIS 3.18, use mimeUris() instead
      */
-    virtual QgsMimeDataUtils::Uri mimeUri() const { return QgsMimeDataUtils::Uri(); }
+    Q_DECL_DEPRECATED virtual QgsMimeDataUtils::Uri mimeUri() const SIP_DEPRECATED;
 
-    enum Capability
-    {
-      NoCapabilities    = 0,
-      SetCrs            = 1 << 0, //!< Can set CRS on layer or group of layers. \deprecated since QGIS 3.6 -- no longer used by QGIS and will be removed in QGIS 4.0
-      Fertile           = 1 << 1, //!< Can create children. Even items without this capability may have children, but cannot create them, it means that children are created by item ancestors.
-      Fast              = 1 << 2, //!< CreateChildren() is fast enough to be run in main thread when refreshing items, most root items (wms,wfs,wcs,postgres...) are considered fast because they are reading data only from QgsSettings
-      Collapse          = 1 << 3, //!< The collapse/expand status for this items children should be ignored in order to avoid undesired network connections (wms etc.)
-      Rename            = 1 << 4, //!< Item can be renamed
-      Delete            = 1 << 5, //!< Item can be deleted
-    };
-    Q_DECLARE_FLAGS( Capabilities, Capability )
+    /**
+     * Returns mime URIs for the data item, most data providers will only return a single URI
+     * but some data collection items (e.g. GPKG, OGR) may report multiple URIs (e.g. for vector and
+     * raster layer types).
+     *
+     * Items that return valid URI will be returned in mime data when dragging a selection from browser model.
+     * \since QGIS 3.18
+     */
+    virtual QgsMimeDataUtils::UriList mimeUris() const;
 
     /**
      * Writes the selected crs into data source. The original data source will be modified when calling this
@@ -253,11 +271,7 @@ class CORE_EXPORT QgsDataItem : public QObject
      *
      * \deprecated since QGIS 3.6. This method is no longer used by QGIS and will be removed in QGIS 4.0.
      */
-    Q_DECL_DEPRECATED virtual bool setCrs( const QgsCoordinateReferenceSystem &crs ) SIP_DEPRECATED
-    {
-      Q_UNUSED( crs )
-      return false;
-    }
+    Q_DECL_DEPRECATED virtual bool setCrs( const QgsCoordinateReferenceSystem &crs ) SIP_DEPRECATED;
 
     /**
      * Sets a new \a name for the item, and returns TRUE if the item was successfully renamed.
@@ -280,32 +294,60 @@ class CORE_EXPORT QgsDataItem : public QObject
      *
      * \see setCapabilities()
      */
-    virtual Capabilities capabilities2() const { return mCapabilities; }
+    virtual Qgis::BrowserItemCapabilities capabilities2() const { return mCapabilities; }
 
     /**
      * Sets the capabilities for the data item.
      *
      * \see capabilities2()
      */
-    virtual void setCapabilities( Capabilities capabilities ) { mCapabilities = capabilities; }
+    virtual void setCapabilities( Qgis::BrowserItemCapabilities capabilities ) SIP_PYNAME( setCapabilitiesV2 ) { mCapabilities = capabilities; }
+
+    /**
+     * \deprecated use setCapabilitiesV2 instead.
+     */
+    Q_DECL_DEPRECATED void setCapabilities( int capabilities ) SIP_DEPRECATED;
 
     // static methods
 
     // Find child index in vector of items using '==' operator
     static int findItem( QVector<QgsDataItem *> items, QgsDataItem *item );
 
+#ifndef SIP_RUN
+
+    /**
+     * Returns a filtered list of data \a items which match the template type.
+     *
+     * \since QGIS 3.38
+     */
+    template<class T>
+    static QList< T * > filteredItems( const QList< QgsDataItem * > &items )
+    {
+      QList< T * > result;
+      result.reserve( items.size() );
+      for ( QgsDataItem *item : items )
+      {
+        if ( T *matchedItem = qobject_cast< T * >( item ) )
+          result << matchedItem;
+      }
+      return result;
+    }
+#endif
+
     // members
 
-    Type type() const { return mType; }
+    Qgis::BrowserItemType type() const { return mType; }
 
     /**
      * Gets item parent. QgsDataItem maintains its own items hierarchy, it does not use
-     *  QObject hierarchy. */
+     * QObject hierarchy.
+    */
     QgsDataItem *parent() const { return mParent; }
 
     /**
      * Set item parent and connect / disconnect parent to / from item signals.
-     *  It does not add itself to parents children (mChildren) */
+     * It does not add itself to parents children (mChildren)
+    */
     void setParent( QgsDataItem *parent );
     QVector<QgsDataItem *> children() const { return mChildren; }
     virtual QIcon icon();
@@ -358,14 +400,12 @@ class CORE_EXPORT QgsDataItem : public QObject
      * sort key.
      *
      * \see setSortKey()
-     * \since QGIS 3.0
      */
     virtual QVariant sortKey() const;
 
     /**
      * Sets a custom sorting \a key for the item.
      * \see sortKey()
-     * \since QGIS 3.0
      */
     void setSortKey( const QVariant &key );
 
@@ -385,6 +425,17 @@ class CORE_EXPORT QgsDataItem : public QObject
     //! Move object and all its descendants to thread
     void moveToThread( QThread *targetThread );
 
+    /**
+     * For data items that represent a DB connection or one of its children,
+     * this method returns a connection.
+     * All other data items will return NULL.
+     *
+     * Ownership of the returned objects is transferred to the caller.
+     *
+     * \since QGIS 3.16
+     */
+    virtual QgsAbstractDatabaseProviderConnection *databaseConnection() const SIP_FACTORY;
+
   protected:
     virtual void populate( const QVector<QgsDataItem *> &children );
 
@@ -399,14 +450,15 @@ class CORE_EXPORT QgsDataItem : public QObject
      * the deferredDelete() returns TRUE and item will be deleted once Populating finished.
      * Items with slow reateChildren() (for example network or database based) may
      * check during createChildren() if deferredDelete() returns TRUE and return from
-     * createChildren() immediately because result will be useless. */
+     * createChildren() immediately because result will be useless.
+    */
     bool deferredDelete() { return mDeferredDelete; }
 
-    Type mType;
-    Capabilities mCapabilities;
+    Qgis::BrowserItemType mType;
+    Qgis::BrowserItemCapabilities mCapabilities = Qgis::BrowserItemCapability::NoCapabilities;
     QgsDataItem *mParent = nullptr;
     QVector<QgsDataItem *> mChildren; // easier to have it always
-    State mState;
+    Qgis::BrowserItemState mState = Qgis::BrowserItemState::NotPopulated;
     QString mName;
     QString mProviderKey;
     // Path is slash ('/') separated chain of item identifiers which are usually item names, but may be different if it is
@@ -460,7 +512,11 @@ class CORE_EXPORT QgsDataItem : public QObject
     void beginRemoveItems( QgsDataItem *parent, int first, int last );
     void endRemoveItems();
     void dataChanged( QgsDataItem *item );
-    void stateChanged( QgsDataItem *item, QgsDataItem::State oldState );
+
+    /**
+     * Emitted when an item's state is changed.
+     */
+    void stateChanged( QgsDataItem *item, Qgis::BrowserItemState oldState );
 
     /**
      * Emitted when the connections of the provider with the specified \a providerKey have changed.
@@ -476,7 +532,6 @@ class CORE_EXPORT QgsDataItem : public QObject
     /**
      * Will request a repaint of this icon.
      *
-     * \since QGIS 3.0
      */
     void updateIcon();
 
@@ -484,288 +539,15 @@ class CORE_EXPORT QgsDataItem : public QObject
     static QVector<QgsDataItem *> runCreateChildren( QgsDataItem *item );
 
     // Set to true if object has to be deleted when possible (nothing running in threads)
-    bool mDeferredDelete;
-    QFutureWatcher< QVector <QgsDataItem *> > *mFutureWatcher;
+    bool mDeferredDelete = false;
+    QFutureWatcher< QVector <QgsDataItem *> > *mFutureWatcher = nullptr;
     // number of items currently in loading (populating) state
     static QgsAnimatedIcon *sPopulatingIcon;
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS( QgsDataItem::Capabilities )
-
 /**
  * \ingroup core
- * Item that represents a layer that can be opened with one of the providers
-*/
-class CORE_EXPORT QgsLayerItem : public QgsDataItem
-{
-    Q_OBJECT
-
-  public:
-    enum LayerType
-    {
-      NoType,
-      Vector,
-      Raster,
-      Point,
-      Line,
-      Polygon,
-      TableLayer,
-      Database,
-      Table,
-      Plugin,    //!< Added in 2.10
-      Mesh,      //!< Added in 3.2
-      VectorTile //!< Added in 3.14
-    };
-
-    Q_ENUM( LayerType )
-
-    QgsLayerItem( QgsDataItem *parent, const QString &name, const QString &path, const QString &uri, LayerType layerType, const QString &providerKey );
-
-    // --- reimplemented from QgsDataItem ---
-
-    bool equal( const QgsDataItem *other ) override;
-
-    bool hasDragEnabled() const override { return true; }
-
-    QgsMimeDataUtils::Uri mimeUri() const override;
-
-    // --- New virtual methods for layer item derived classes ---
-
-    //! Returns QgsMapLayerType
-    QgsMapLayerType mapLayerType() const;
-
-    /**
-     * Returns the layer item type corresponding to a QgsMapLayer \a layer.
-     * \since QGIS 3.6
-     */
-    static LayerType typeFromMapLayer( QgsMapLayer *layer );
-
-    //! Returns layer uri or empty string if layer cannot be created
-    QString uri() const { return mUri; }
-
-    //! Returns provider key
-    QString providerKey() const { return mProviderKey; }
-
-    /**
-     * Returns the supported CRS
-     *  \since QGIS 2.8
-     */
-    QStringList supportedCrs() const { return mSupportedCRS; }
-
-    /**
-     * Returns the supported formats
-     *  \since QGIS 2.8
-     */
-    QStringList supportedFormats() const { return mSupportFormats; }
-
-    /**
-     * Returns comments of the layer
-     * \since QGIS 2.12
-     */
-    virtual QString comments() const { return QString(); }
-
-    /**
-     * Returns the string representation of the given \a layerType
-     * \since QGIS 3
-     */
-    static QString layerTypeAsString( LayerType layerType );
-
-    /**
-     * Returns the icon name of the given \a layerType
-     * \since QGIS 3
-     */
-    static QString iconName( LayerType layerType );
-
-    /**
-     * Delete this layer item
-     * Use QgsDataItemGuiProvider::deleteLayer instead
-     *
-     * \deprecated QGIS 3.10
-     */
-    Q_DECL_DEPRECATED virtual bool deleteLayer() SIP_DEPRECATED;
-
-  protected:
-    //! The URI
-    QString mUri;
-    //! The layer type
-    LayerType mLayerType;
-    //! The list of supported CRS
-    QStringList mSupportedCRS;
-    //! The list of supported formats
-    QStringList mSupportFormats;
-
-  public:
-    static QIcon iconPoint();
-    static QIcon iconLine();
-    static QIcon iconPolygon();
-    static QIcon iconTable();
-    static QIcon iconRaster();
-    static QIcon iconDefault();
-    //! Returns icon for mesh layer type
-    static QIcon iconMesh();
-    //! Returns icon for vector tile layer
-    static QIcon iconVectorTile();
-
-    //! \returns the layer name
-    virtual QString layerName() const { return name(); }
-};
-
-
-/**
- * \ingroup core
- * A Collection: logical collection of layers or subcollections, e.g. GRASS location/mapset, database? wms source?
-*/
-class CORE_EXPORT QgsDataCollectionItem : public QgsDataItem
-{
-    Q_OBJECT
-  public:
-
-    /**
-     * Constructor for QgsDataCollectionItem, with the specified \a parent item.
-     *
-     * The \a name argument specifies the text to show in the model for the item. A translated string should
-     * be used wherever appropriate.
-     *
-     * The \a path argument gives the item path in the browser tree. The \a path string can take any form,
-     * but QgsDataCollectionItem items pointing to different logical locations should always use a different item \a path.
-     *
-     * The optional \a providerKey string can be used to specify the key for the QgsDataItemProvider that created this item.
-     */
-    QgsDataCollectionItem( QgsDataItem *parent SIP_TRANSFERTHIS, const QString &name, const QString &path = QString(), const QString &providerKey = QString() );
-
-    ~QgsDataCollectionItem() override;
-
-    void addChild( QgsDataItem *item SIP_TRANSFER ) { mChildren.append( item ); }
-
-    /**
-     * Returns the standard browser directory icon.
-     * \see iconDataCollection()
-     */
-    static QIcon iconDir();
-
-    /**
-     * Returns the standard browser data collection icon.
-     * \see iconDir()
-     */
-    static QIcon iconDataCollection();
-
-  protected:
-
-    /**
-     * Shared open directory icon.
-     * \since QGIS 3.4
-     */
-    static QIcon openDirIcon();
-
-    /**
-     * Shared home directory icon.
-     * \since QGIS 3.4
-     */
-    static QIcon homeDirIcon();
-};
-
-/**
- * \ingroup core
- * A directory: contains subdirectories and layers
-*/
-class CORE_EXPORT QgsDirectoryItem : public QgsDataCollectionItem
-{
-    Q_OBJECT
-  public:
-
-    /**
-     * Constructor for QgsDirectoryItem, with the specified \a parent item.
-     *
-     * The \a name argument specifies the text to show in the model for the item. This is usually
-     * the directory name, but in certain cases may differ for special directories (e.g. "Home").
-     * If a non-directory-name text is used, it should be a translated string when appropriate.
-     *
-     * The \a path argument specifies the directory path in the file system (e.g. "/home/gsherman/stuff"). A valid
-     * directory path must be specified.
-     */
-    QgsDirectoryItem( QgsDataItem *parent SIP_TRANSFERTHIS, const QString &name, const QString &path );
-
-
-    // TODO QGIS 4.0 -- rename "name" to "title" or "text" or something more descriptive, and "path" to something
-    // else to clarify the role of dirPath vs path
-
-    /**
-     * Constructor for QgsDirectoryItem, with the specified \a parent item.
-     *
-     * The \a name argument specifies the text to show in the model for the item. This is usually
-     * the directory name, but in certain cases may differ for special directories (e.g. "Home").
-     * If a non-directory-name text is used, it should be a translated string when appropriate.
-     *
-     * The \a dirPath argument specifies the directory path in the file system (e.g. "/home/gsherman/stuff"). A valid
-     * directory path must be specified.
-     *
-     * The \a path argument gives the item path in the browser tree. The \a path string can take any form, but is usually
-     * the same as \a dirPath or \a dirPath with a prefix, e.g. "favorites:/home/gsherman/Downloads"). QgsDirectoryItem
-     * items pointing to different \a dirPaths should always use a different item \a path.
-     *
-     * The optional \a providerKey string can be used to specify the key for the QgsDataItemProvider that created this item.
-     */
-    QgsDirectoryItem( QgsDataItem *parent SIP_TRANSFERTHIS, const QString &name, const QString &dirPath, const QString &path, const QString &providerKey = QString() );
-
-    void setState( State state ) override;
-
-    QVector<QgsDataItem *> createChildren() override;
-
-    /**
-     * Returns the full path to the directory the item represents.
-     */
-    QString dirPath() const { return mDirPath; }
-
-    bool equal( const QgsDataItem *other ) override;
-    QIcon icon() override;
-    Q_DECL_DEPRECATED QWidget *paramWidget() override SIP_FACTORY SIP_DEPRECATED;
-    bool hasDragEnabled() const override { return true; }
-    QgsMimeDataUtils::Uri mimeUri() const override;
-
-    //! Check if the given path is hidden from the browser model
-    static bool hiddenPath( const QString &path );
-
-  public slots:
-    void childrenCreated() override;
-    void directoryChanged();
-
-  protected:
-    void init();
-    QString mDirPath;
-
-  private:
-    QFileSystemWatcher *mFileSystemWatcher = nullptr;
-    bool mRefreshLater;
-    QDateTime mLastScan;
-};
-
-/**
- * \ingroup core
- Data item that can be used to represent QGIS projects.
- */
-class CORE_EXPORT QgsProjectItem : public QgsDataItem
-{
-    Q_OBJECT
-  public:
-
-    /**
-     * \brief A data item holding a reference to a QGIS project file.
-     * \param parent The parent data item.
-     * \param name The name of the of the project. Displayed to the user.
-     * \param path The full path to the project.
-     * \param providerKey key of the provider that created this item
-     */
-    QgsProjectItem( QgsDataItem *parent, const QString &name, const QString &path, const QString &providerKey = QString() );
-
-    bool hasDragEnabled() const override { return true; }
-
-    QgsMimeDataUtils::Uri mimeUri() const override;
-
-};
-
-/**
- * \ingroup core
- Data item that can be used to report problems (e.g. network error)
+ * \brief Data item that can be used to report problems (e.g. network error)
  */
 class CORE_EXPORT QgsErrorItem : public QgsDataItem
 {
@@ -774,172 +556,15 @@ class CORE_EXPORT QgsErrorItem : public QgsDataItem
 
     QgsErrorItem( QgsDataItem *parent, const QString &error, const QString &path );
 
-};
-
-// ---------
-
-// TODO: move to qgis_gui for QGIS 4
-
-/**
- * \ingroup core
- * \class QgsDirectoryParamWidget
- *
- * Browser parameter widget implementation for directory items.
- */
-class CORE_EXPORT QgsDirectoryParamWidget : public QTreeWidget
-{
-    Q_OBJECT
-
-  public:
-    QgsDirectoryParamWidget( const QString &path, QWidget *parent SIP_TRANSFERTHIS = nullptr );
-
-  protected:
-    void mousePressEvent( QMouseEvent *event ) override;
-
-  public slots:
-    void showHideColumn();
-};
-
-/**
- * \ingroup core
- * Contains various Favorites directories
- * \since QGIS 3.0
-*/
-class CORE_EXPORT QgsFavoritesItem : public QgsDataCollectionItem
-{
-    Q_OBJECT
-  public:
-
-    /**
-     * Constructor for QgsFavoritesItem. Accepts a path argument specifying the file path associated with
-     * the item.
-     */
-    QgsFavoritesItem( QgsDataItem *parent, const QString &name, const QString &path = QString() );
-
-    QVector<QgsDataItem *> createChildren() override;
-
-    /**
-     * Adds a new \a directory to the favorites group.
-     *
-     * If \a name is specified, it will be used as the favorite's name. Otherwise
-     * the name will be set to match \a directory.
-     *
-     * \see removeDirectory()
-     */
-    void addDirectory( const QString &directory, const QString &name = QString() );
-
-    /**
-     * Removes an existing directory from the favorites group.
-     * \see addDirectory()
-     */
-    void removeDirectory( QgsDirectoryItem *item );
-
-    /**
-     * Renames the stored favorite with corresponding \a path a new \a name.
-     */
-    void renameFavorite( const QString &path, const QString &name );
-
-    //! Icon for favorites group
-    static QIcon iconFavorites();
-
-    QVariant sortKey() const override;
-
-  private:
-    QVector<QgsDataItem *> createChildren( const QString &favDir, const QString &name );
-};
-
-/**
- * \ingroup core
- * A zip file: contains layers, using GDAL/OGR VSIFILE mechanism
-*/
-class CORE_EXPORT QgsZipItem : public QgsDataCollectionItem
-{
-    Q_OBJECT
-
-  protected:
-    QString mFilePath;
-    QString mVsiPrefix;
-    QStringList mZipFileList;
-
-  public:
-    //! Constructor
-    QgsZipItem( QgsDataItem *parent, const QString &name, const QString &path );
-
-    //! Constructor
-    QgsZipItem( QgsDataItem *parent, const QString &name, const QString &filePath, const QString &path, const QString &providerKey = QString() );
-
-    QVector<QgsDataItem *> createChildren() override;
-    QStringList getZipFileList();
-
-    //! \note not available via Python bindings
-    static QVector<dataItem_t *> sDataItemPtr SIP_SKIP;
-    static QStringList sProviderNames;
-
-    static QString vsiPrefix( const QString &uri ) { return qgsVsiPrefix( uri ); }
-
-    /**
-     * Creates a new data item from the specified path.
-     */
-    static QgsDataItem *itemFromPath( QgsDataItem *parent, const QString &path, const QString &name ) SIP_FACTORY;
-
-    /**
-    * Creates a new data item from the specified path.
-    * \note available in Python as itemFromFilePath
-    */
-    static QgsDataItem *itemFromPath( QgsDataItem *parent, const QString &filePath, const QString &name, const QString &path ) SIP_FACTORY SIP_PYNAME( itemFromFilePath );
-
-    static QIcon iconZip();
-
-  private:
-    void init();
-};
-
-
-///@cond PRIVATE
-#ifndef SIP_RUN
-
-/**
- * \ingroup core
- * A directory item showing the current project directory.
- * \since QGIS 3.0
-*/
-class CORE_EXPORT QgsProjectHomeItem : public QgsDirectoryItem
-{
-    Q_OBJECT
-
-  public:
-
-    QgsProjectHomeItem( QgsDataItem *parent, const QString &name, const QString &dirPath, const QString &path );
-
-    QIcon icon() override;
-    QVariant sortKey() const override;
-
-};
-
-/**
- * \ingroup core
- * A directory item showing the a single favorite directory.
- * \since QGIS 3.0
-*/
-Q_NOWARN_DEPRECATED_PUSH  // rename is deprecated
-class CORE_EXPORT QgsFavoriteItem : public QgsDirectoryItem
-{
-    Q_OBJECT
-
-  public:
-
-    QgsFavoriteItem( QgsFavoritesItem *parent, const QString &name, const QString &dirPath, const QString &path );
-
-    bool rename( const QString &name ) override;
-
-  private:
-
-    QgsFavoritesItem *mFavorites = nullptr;
-};
-Q_NOWARN_DEPRECATED_POP
-
+#ifdef SIP_RUN
+    SIP_PYOBJECT __repr__();
+    % MethodCode
+    QString str = QStringLiteral( "<QgsErrorItem: \"%1\" %2>" ).arg( sipCpp->name(), sipCpp->path() );
+    sipRes = PyUnicode_FromString( str.toUtf8().constData() );
+    % End
 #endif
-///@endcond
+
+};
 
 #endif // QGSDATAITEM_H
 
