@@ -28,6 +28,7 @@
 class QgsDataItem;
 class QgsMessageBar;
 class QgsLayerItem;
+class QgsBrowserTreeView;
 
 /**
  * \class QgsDataItemGuiContext
@@ -64,9 +65,27 @@ class GUI_EXPORT QgsDataItemGuiContext
      */
     void setMessageBar( QgsMessageBar *bar );
 
+    /**
+     * Returns the associated view.
+     *
+     * \see setView()
+     * \since QGIS 3.28
+     */
+    QgsBrowserTreeView *view() const;
+
+    /**
+     * Sets the associated \a view.
+     *
+     * \see view()
+     * \since QGIS 3.28
+     */
+    void setView( QgsBrowserTreeView *view );
+
   private:
 
     QgsMessageBar *mMessageBar = nullptr;
+
+    QgsBrowserTreeView *mView = nullptr;
 };
 
 Q_DECLARE_METATYPE( QgsDataItemGuiContext );
@@ -120,6 +139,19 @@ class GUI_EXPORT QgsDataItemGuiProvider
     virtual void populateContextMenu( QgsDataItem *item, QMenu *menu,
                                       const QList<QgsDataItem *> &selectedItems, QgsDataItemGuiContext context );
 
+    /**
+     * Returns the provider's precedence to use when populating context menus via calls to populateContextMenu().
+     *
+     * Providers which return larger values will be called AFTER other providers when the menu is being populated.
+     * This allows them to nicely insert their corresponding menu items in the desired location with respect to
+     * existing items added by other providers.
+     *
+     * The default implementation returns 0.
+     *
+     * \since QGIS 3.22
+     */
+    virtual int precedenceWhenPopulatingMenus() const;
+
     /**
      * Sets a new \a name for the item, and returns TRUE if the item was successfully renamed.
      *
