@@ -35,8 +35,8 @@ class QgsExpressionContextScope;
 
 /**
  * \ingroup core
-  * A abstract base class for defining QgsExpression functions.
-  */
+ * \brief A abstract base class for defining QgsExpression functions.
+ */
 class CORE_EXPORT QgsExpressionFunction
 {
   public:
@@ -48,8 +48,7 @@ class CORE_EXPORT QgsExpressionFunction
 
     /**
      * \ingroup core
-      * Represents a single parameter passed to a function.
-      * \since QGIS 2.16
+      * \brief Represents a single parameter passed to a function.
       */
     class CORE_EXPORT Parameter
     {
@@ -123,7 +122,6 @@ class CORE_EXPORT QgsExpressionFunction
 
     /**
      * Constructor for function which uses unnamed parameters and group list
-     * \since QGIS 3.0
      */
     QgsExpressionFunction( const QString &fnname,
                            int params,
@@ -144,7 +142,6 @@ class CORE_EXPORT QgsExpressionFunction
 
     /**
      * Constructor for function which uses named parameter list.
-     * \since QGIS 2.16
      */
     QgsExpressionFunction( const QString &fnname,
                            const QgsExpressionFunction::ParameterList &params,
@@ -165,7 +162,6 @@ class CORE_EXPORT QgsExpressionFunction
 
     /**
      * Constructor for function which uses named parameter list and group list.
-     * \since QGIS 3.0
      */
     QgsExpressionFunction( const QString &fnname,
                            const QgsExpressionFunction::ParameterList &params,
@@ -209,7 +205,6 @@ class CORE_EXPORT QgsExpressionFunction
 
     /**
      * Returns the list of named parameters for the function, if set.
-     * \since QGIS 2.16
     */
     const QgsExpressionFunction::ParameterList &parameters() const { return mParameterList; }
 
@@ -220,7 +215,6 @@ class CORE_EXPORT QgsExpressionFunction
      * Returns a list of possible aliases for the function. These include
      * other permissible names for the function, e.g., deprecated names.
      * \returns list of known aliases
-     * \since QGIS 2.9
      */
     virtual QStringList aliases() const;
 
@@ -239,7 +233,6 @@ class CORE_EXPORT QgsExpressionFunction
      * By default this will return TRUE, if all arguments that have been passed to the function
      * are also static.
      *
-     * \since QGIS 3.0
      */
     virtual bool isStatic( const QgsExpressionNodeFunction *node, QgsExpression *parent, const QgsExpressionContext *context ) const;
 
@@ -249,7 +242,6 @@ class CORE_EXPORT QgsExpressionFunction
      * This can be used by functions to do any preparation steps that might help to speedup the upcoming
      * evaluation.
      *
-     * \since QGIS 3.0
      */
     virtual bool prepare( const QgsExpressionNodeFunction *node, QgsExpression *parent, const QgsExpressionContext *context ) const;
 
@@ -259,20 +251,17 @@ class CORE_EXPORT QgsExpressionFunction
      * attributes are required.
      * If in doubt this will return more fields than strictly required.
      *
-     * \since QGIS 3.0
      */
     virtual QSet<QString> referencedColumns( const QgsExpressionNodeFunction *node ) const;
 
     /**
      * Returns whether the function is only available if provided by a QgsExpressionContext object.
-     * \since QGIS 2.12
      */
     bool isContextual() const { return mIsContextual; }
 
     /**
      * Returns TRUE if the function is deprecated and should not be presented as a valid option
      * to users in expression builders.
-     * \since QGIS 3.0
      */
     virtual bool isDeprecated() const;
 
@@ -285,7 +274,6 @@ class CORE_EXPORT QgsExpressionFunction
     /**
      * Returns a list of the groups the function belongs to.
      * \see group()
-     * \since QGIS 3.0
     */
     QStringList groups() const { return mGroups; }
 
@@ -325,7 +313,6 @@ class CORE_EXPORT QgsExpressionFunction
      * This can be used as callback for custom implementations of subclasses. It is the default for implementation
      * for StaticFunction::isStatic.
      *
-     * \since QGIS 3.0
      */
     static bool allParamsStatic( const QgsExpressionNodeFunction *node, QgsExpression *parent, const QgsExpressionContext *context );
 
@@ -342,7 +329,7 @@ class CORE_EXPORT QgsExpressionFunction
 
 /**
  * \ingroup core
-  * c++ helper class for defining QgsExpression functions.
+  * \brief c++ helper class for defining QgsExpression functions.
   * \note not available in Python bindings
   */
 #ifndef SIP_RUN
@@ -371,6 +358,28 @@ class QgsStaticExpressionFunction : public QgsExpressionFunction
     {
     }
 
+    /**
+     * Static function for evaluation against a QgsExpressionContext, using an unnamed list of parameter values and list
+     * of groups.
+     */
+    QgsStaticExpressionFunction( const QString &fnname,
+                                 int params,
+                                 FcnEval fcn,
+                                 const QStringList &groups,
+                                 const QString &helpText = QString(),
+                                 bool usesGeometry = false,
+                                 const QSet<QString> &referencedColumns = QSet<QString>(),
+                                 bool lazyEval = false,
+                                 const QStringList &aliases = QStringList(),
+                                 bool handlesNull = false )
+      : QgsExpressionFunction( fnname, params, groups, helpText, lazyEval, handlesNull )
+      , mFnc( fcn )
+      , mAliases( aliases )
+      , mUsesGeometry( usesGeometry )
+      , mReferencedColumns( referencedColumns )
+    {
+    }
+
     /**
      * Static function for evaluation against a QgsExpressionContext, using a named list of parameter values.
      */
@@ -451,6 +460,13 @@ class QgsStaticExpressionFunction : public QgsExpressionFunction
 
     bool usesGeometry( const QgsExpressionNodeFunction *node ) const override;
 
+    /**
+     * Set a function that will be called when determining if the function requires feature geometry or not.
+     *
+     * \since QGIS 3.30
+     */
+    void setUsesGeometryFunction( const std::function< bool( const QgsExpressionNodeFunction *node )> &usesGeometry );
+
     QSet<QString> referencedColumns( const QgsExpressionNodeFunction *node ) const override;
 
     bool isStatic( const QgsExpressionNodeFunction *node, QgsExpression *parent, const QgsExpressionContext *context ) const override;
@@ -465,6 +481,7 @@ class QgsStaticExpressionFunction : public QgsExpressionFunction
      */
     void setIsStaticFunction( const std::function< bool ( const QgsExpressionNodeFunction *, QgsExpression *, const QgsExpressionContext * ) > &isStatic );
 
+
     /**
      * Tag this function as either static or not static.
      * This will indicate that the function is always expected to return the same value for
@@ -500,7 +517,7 @@ class QgsStaticExpressionFunction : public QgsExpressionFunction
 };
 
 /**
- * Handles the ``array_foreach(array, expression)`` expression function.
+ * \brief Handles the array looping``array_Foreach(array, expression)`` expression function.
  * It temporarily appends a new scope to the expression context.
  *
  * \ingroup core
@@ -523,7 +540,7 @@ class QgsArrayForeachExpressionFunction : public QgsExpressionFunction
 };
 
 /**
- * Handles the ``array_filter(array, expression)`` expression function.
+ * \brief Handles the ``array_filter(array, expression)`` expression function.
  * It temporarily appends a new scope to the expression context.
  *
  * \ingroup core
@@ -546,13 +563,12 @@ class QgsArrayFilterExpressionFunction : public QgsExpressionFunction
 };
 
 /**
- * Handles the ``with_variable(name, value, node)`` expression function.
+ * \brief Handles the ``with_variable(name, value, node)`` expression function.
  * It temporarily appends a new scope to the expression context for all nested
  * nodes.
  *
  * \ingroup core
  * \note Not available in Python bindings
- * \since QGIS 3.0
  */
 class QgsWithVariableExpressionFunction : public QgsExpressionFunction
 {
