@@ -19,8 +19,8 @@
 
 #include "qgis_analysis.h"
 #include "qgsfeature.h"
-#include "geometry/qgsabstractgeometry.h"
-#include "geometry/qgspoint.h"
+#include "qgsabstractgeometry.h"
+#include "qgspoint.h"
 #include "qgsgeometrycheckcontext.h"
 #include <qmath.h>
 
@@ -119,7 +119,7 @@ class ANALYSIS_EXPORT QgsGeometryCheckerUtils
          */
         LayerFeatures( const QMap<QString, QgsFeaturePool *> &featurePools,
                        const QMap<QString, QgsFeatureIds> &featureIds,
-                       const QList<QgsWkbTypes::GeometryType> &geometryTypes,
+                       const QList<Qgis::GeometryType> &geometryTypes,
                        QgsFeedback *feedback,
                        const QgsGeometryCheckContext *context,
                        bool useMapCrs = false );
@@ -129,7 +129,7 @@ class ANALYSIS_EXPORT QgsGeometryCheckerUtils
          */
         LayerFeatures( const QMap<QString, QgsFeaturePool *> &featurePools,
                        const QList<QString> &layerIds, const QgsRectangle &extent,
-                       const QList<QgsWkbTypes::GeometryType> &geometryTypes,
+                       const QList<Qgis::GeometryType> &geometryTypes,
                        const QgsGeometryCheckContext *context );
 
         /**
@@ -204,7 +204,7 @@ class ANALYSIS_EXPORT QgsGeometryCheckerUtils
         QMap<QString, QgsFeatureIds> mFeatureIds;
         QList<QString> mLayerIds;
         QgsRectangle mExtent;
-        QList<QgsWkbTypes::GeometryType> mGeometryTypes;
+        QList<Qgis::GeometryType> mGeometryTypes;
         QgsFeedback *mFeedback = nullptr;
         const QgsGeometryCheckContext *mContext = nullptr;
         bool mUseMapCrs = true;
@@ -251,19 +251,6 @@ class ANALYSIS_EXPORT QgsGeometryCheckerUtils
 
     static double sharedEdgeLength( const QgsAbstractGeometry *geom1, const QgsAbstractGeometry *geom2, double tol );
 
-    /**
-       * \brief Determine whether two points are equal up to the specified tolerance
-       * \param p1 The first point
-       * \param p2 The second point
-       * \param tol The tolerance
-       * \returns Whether the points are equal
-       */
-    static inline bool pointsFuzzyEqual( const QgsPointXY &p1, const QgsPointXY &p2, double tol )
-    {
-      double dx = p1.x() - p2.x(), dy = p1.y() - p2.y();
-      return ( dx * dx + dy * dy ) < tol * tol;
-    }
-
     static inline bool canDeleteVertex( const QgsAbstractGeometry *geom, int iPart, int iRing )
     {
       const int nVerts = geom->vertexCount( iPart, iRing );
