@@ -57,7 +57,6 @@ class QgsMasterLayoutInterface;
  * If you are creating a new QgsLayoutItem configuration widget, you should instead
  * inherit from QgsLayoutItemBaseWidget (rather then directly working with QgsLayoutConfigObject).
  *
- * \since QGIS 3.0
 */
 class GUI_EXPORT QgsLayoutConfigObject: public QObject
 {
@@ -117,7 +116,6 @@ class GUI_EXPORT QgsLayoutConfigObject: public QObject
  * this base class.
  *
  *
- * \since QGIS 3.0
 */
 class GUI_EXPORT QgsLayoutItemBaseWidget: public QgsPanelWidget
 {
@@ -212,7 +210,6 @@ class GUI_EXPORT QgsLayoutItemBaseWidget: public QgsPanelWidget
  * \ingroup gui
  * \brief A widget for controlling the common properties of layout items (e.g. position and size, background, stroke, frame).
  * This widget can be embedded into other layout item widgets.
- * \since QGIS 3.0
 */
 class GUI_EXPORT QgsLayoutItemPropertiesWidget: public QWidget, private Ui::QgsLayoutItemWidgetBase
 {
@@ -270,7 +267,7 @@ class GUI_EXPORT QgsLayoutItemPropertiesWidget: public QWidget, private Ui::QgsL
 //    void on_mTransparencySlider_valueChanged( int value );
 //    void on_mTransparencySpinBox_valueChanged( int value );
     void mStrokeWidthSpinBox_valueChanged( double d );
-    void strokeUnitChanged( QgsUnitTypes::LayoutUnit unit );
+    void strokeUnitChanged( Qgis::LayoutUnit unit );
     void mFrameGroupBox_toggled( bool state );
     void mFrameJoinStyleCombo_currentIndexChanged( int index );
     void mBackgroundGroupBox_toggled( bool state );
@@ -280,10 +277,10 @@ class GUI_EXPORT QgsLayoutItemPropertiesWidget: public QWidget, private Ui::QgsL
     void mPageSpinBox_valueChanged( int );
     void mXPosSpin_valueChanged( double );
     void mYPosSpin_valueChanged( double );
-    void positionUnitsChanged( QgsUnitTypes::LayoutUnit unit );
+    void positionUnitsChanged( Qgis::LayoutUnit unit );
     void mWidthSpin_valueChanged( double );
     void mHeightSpin_valueChanged( double );
-    void sizeUnitsChanged( QgsUnitTypes::LayoutUnit unit );
+    void sizeUnitsChanged( Qgis::LayoutUnit unit );
 
     void mUpperLeftCheckBox_stateChanged( bool state );
     void mUpperMiddleCheckBox_stateChanged( bool state );
