@@ -86,6 +86,7 @@ class GUI_EXPORT QgsLayoutMapWidget: public QgsLayoutItemBaseWidget, private Ui:
 
     void mAddGridPushButton_clicked();
     void mRemoveGridPushButton_clicked();
+    void mCopyGridPushButton_clicked();
     void mGridUpButton_clicked();
     void mGridDownButton_clicked();
 
@@ -110,6 +111,9 @@ class GUI_EXPORT QgsLayoutMapWidget: public QgsLayoutItemBaseWidget, private Ui:
     void mTemporalCheckBox_toggled( bool checked );
     void updateTemporalExtent();
 
+    void mElevationRangeCheckBox_toggled( bool checked );
+    void updateZRange();
+
   protected:
     bool setNewItem( QgsLayoutItem *item ) override;
 
