@@ -18,17 +18,9 @@
 
 #include "qgis_3d.h"
 #include "qgsabstractmaterialsettings.h"
-#include "qgspropertycollection.h"
 
 #include <QColor>
 
-#ifndef SIP_RUN
-namespace Qt3DRender
-{
-  class QGeometry;
-}
-#endif //SIP_RUN
-
 class QDomElement;
 
 /**
@@ -39,7 +31,6 @@ class QDomElement;
  * \warning This is not considered stable API, and may change in future QGIS releases. It is
  * exposed to the Python bindings as a tech preview only.
  *
- * \since QGIS 3.0
  */
 class _3D_EXPORT QgsPhongMaterialSettings : public QgsAbstractMaterialSettings
 {
@@ -71,13 +62,46 @@ class _3D_EXPORT QgsPhongMaterialSettings : public QgsAbstractMaterialSettings
     //! Returns specular color component
     QColor specular() const { return mSpecular; }
     //! Returns shininess of the surface
-    float shininess() const { return mShininess; }
+    double shininess() const { return mShininess; }
 
     /**
      * Returns the opacity of the surface
      * \since QGIS 3.26
      */
-    float opacity() const { return mOpacity; }
+    double opacity() const { return mOpacity; }
+
+    /**
+     * Returns the coefficient for the ambient color contribution (ie strength factor of the ambient color).
+     *
+     * \see setAmbientCoefficient()
+     * \see diffuseCoefficient()
+     * \see specularCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    double ambientCoefficient() const { return mAmbientCoefficient; }
+
+    /**
+     * Returns the coefficient for the diffuse color contribution (ie strength factor of the diffuse color).
+     *
+     * \see setDiffuseCoefficient()
+     * \see ambientCoefficient()
+     * \see specularCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    double diffuseCoefficient() const { return mDiffuseCoefficient; }
+
+    /**
+     * Returns the coefficient for the specular color contribution (ie strength factor of the specular color).
+     *
+     * \see setSpecularCoefficient()
+     * \see diffuseCoefficient()
+     * \see ambientCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    double specularCoefficient() const { return mSpecularCoefficient; }
 
     QMap<QString, QString> toExportParameters() const override;
 
@@ -91,23 +115,58 @@ class _3D_EXPORT QgsPhongMaterialSettings : public QgsAbstractMaterialSettings
     void setShininess( float shininess ) { mShininess = shininess; }
 
     /**
-     * Sets shininess of the surface
+     * Sets opacity of the surface
      * \since QGIS 3.26
      */
-    void setOpacity( float opacity ) { mOpacity = opacity; }
+    void setOpacity( double opacity ) { mOpacity = opacity; }
 
+    /**
+     * Sets the \a coefficient for the ambient color contribution (ie strength factor of the ambient color).
+     *
+     * \see ambientCoefficient()
+     * \see setDiffuseCoefficient()
+     * \see setSpecularCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    void setAmbientCoefficient( double coefficient ) { mAmbientCoefficient = coefficient; }
 
+    /**
+     * Sets the \a coefficient for the diffuse color contribution (ie strength factor of the diffuse color).
+     *
+     * \see diffuseCoefficient()
+     * \see setAmbientCoefficient()
+     * \see setSpecularCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    void setDiffuseCoefficient( double coefficient ) { mDiffuseCoefficient = coefficient; }
+
+    /**
+     * Sets the \a coefficient for the specular color contribution (ie strength factor of the specular color).
+     *
+     * \see specularCoefficient()
+     * \see setDiffuseCoefficient()
+     * \see setAmbientCoefficient()
+     *
+     * \since QGIS 3.36
+     */
+    void setSpecularCoefficient( double coefficient ) { mSpecularCoefficient = coefficient; }
 
     void readXml( const QDomElement &elem, const QgsReadWriteContext &context ) override;
     void writeXml( QDomElement &elem, const QgsReadWriteContext &context ) const override;
 
 #ifndef SIP_RUN
     Qt3DRender::QMaterial *toMaterial( QgsMaterialSettingsRenderingTechnique technique, const QgsMaterialContext &context ) const override SIP_FACTORY;
-    void addParametersToEffect( Qt3DRender::QEffect *effect ) const override;
+    void addParametersToEffect( Qt3DRender::QEffect *effect, const QgsMaterialContext &materialContext ) const override;
 
     QByteArray dataDefinedVertexColorsAsByte( const QgsExpressionContext &expressionContext ) const override;
     int dataDefinedByteStride() const override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void applyDataDefinedToGeometry( Qt3DRender::QGeometry *geometry, int vertexCount, const QByteArray &data ) const override;
+#else
+    void applyDataDefinedToGeometry( Qt3DCore::QGeometry *geometry, int vertexCount, const QByteArray &data ) const override;
+#endif
 #endif
 
     // TODO c++20 - replace with = default
@@ -115,18 +174,28 @@ class _3D_EXPORT QgsPhongMaterialSettings : public QgsAbstractMaterialSettings
     {
       return mAmbient == other.mAmbient &&
              mDiffuse == other.mDiffuse &&
+             mOpacity == other.mOpacity &&
              mSpecular == other.mSpecular &&
-             mShininess == other.mShininess;
+             mShininess == other.mShininess &&
+             mAmbientCoefficient == other.mAmbientCoefficient &&
+             mDiffuseCoefficient == other.mDiffuseCoefficient &&
+             mSpecularCoefficient == other.mSpecularCoefficient;
     }
 
   private:
     QColor mAmbient{ QColor::fromRgbF( 0.1f, 0.1f, 0.1f, 1.0f ) };
     QColor mDiffuse{ QColor::fromRgbF( 0.7f, 0.7f, 0.7f, 1.0f ) };
     QColor mSpecular{ QColor::fromRgbF( 1.0f, 1.0f, 1.0f, 1.0f ) };
-    float mShininess = 0.0f;
-    float mOpacity = 1.0f;
+    double mShininess = 0.0;
+
+    double mAmbientCoefficient = 1.0;
+    double mDiffuseCoefficient = 1.0;
+    double mSpecularCoefficient = 1.0;
+
+    double mOpacity = 1.0;
 
     //! Constructs a material from shader files
+    Qt3DRender::QMaterial *constantColorMaterial( const QgsMaterialContext &context ) const;
     Qt3DRender::QMaterial *dataDefinedMaterial() const;
 };
 
