@@ -24,9 +24,9 @@
 
 /**
  * \ingroup gui
- * A combobox which lets the user select map scale from predefined list
+ * \brief A combobox which lets the user select map scale from predefined list
  * and highlights nearest to current scale value
- **/
+ */
 class GUI_EXPORT QgsScaleComboBox : public QComboBox
 {
     Q_OBJECT
@@ -59,6 +59,15 @@ class GUI_EXPORT QgsScaleComboBox : public QComboBox
      */
     double scale() const;
 
+    /**
+     * Returns TRUE if the combo box is currently set to a "null" value.
+     *
+     * \see setAllowNull()
+     * \see setNull()
+     * \since QGIS 3.8
+     */
+    bool isNull() const;
+
     /**
      * Returns the minimum scale, or 0 if no minimum scale set.
      * The \a scale value indicates the scale denominator, e.g. 1000.0 for a 1:1000 map.
@@ -79,11 +88,39 @@ class GUI_EXPORT QgsScaleComboBox : public QComboBox
     /**
      * Helper function to convert a scale \a string to double.
      * The returned value indicates the scale denominator, e.g. 1000.0 for a 1:1000 map.
-     * If specified, \a ok will be set to true if the string was successfully interpreted as a scale.
+     * If specified, \a ok will be set to TRUE if the string was successfully interpreted as a scale.
      * \see toString()
      */
     static double toDouble( const QString &string, bool *ok = nullptr );
 
+    /**
+     * Sets whether the scale combobox can be set to a NULL value.
+     * \see allowNull()
+     * \see isNull()
+     * \see setNull()
+     * \since QGIS 3.8
+     */
+    void setAllowNull( bool allowNull );
+
+    /**
+     * Returns TRUE if the combobox can be set to a NULL value.
+     * \see setAllowNull()
+     * \see isNull()
+     * \see setNull()
+     * \since QGIS 3.8
+     */
+    bool allowNull() const;
+
+    /**
+     * Sets the list of predefined \a scales to show in the combobox. List elements
+     * are expected to be scale denominators, e.g. 1000.0 for a 1:1000 map.
+     *
+     * If \a scales is empty then the default user scale options will be used instead.
+     *
+     * \since QGIS 3.38
+    */
+    void setPredefinedScales( const QVector< double > &scales );
+
   signals:
 
     /**
@@ -115,6 +152,17 @@ class GUI_EXPORT QgsScaleComboBox : public QComboBox
      */
     void setMinScale( double scale );
 
+    /**
+     * Sets the combo box to the null value.
+     *
+     * This only has an effect if allowNull() is TRUE.
+     *
+     * \see allowNull()
+     * \see isNull()
+     * \since QGIS 3.8
+     */
+    void setNull();
+
   protected:
     void showPopup() override;
 
@@ -124,6 +172,7 @@ class GUI_EXPORT QgsScaleComboBox : public QComboBox
   private:
     double mScale = 1.0;
     double mMinScale = 0.0;
+    bool mAllowNull = false;
 };
 
 #endif // QGSSCALECOMBOBOX_H
