@@ -28,7 +28,7 @@
 #include "qgssymbollayerutils.h" // QgsStringMap
 #include "qgstextformat.h"
 #include "qgspallabeling.h"
-#include "layertree/qgslegendpatchshape.h"
+#include "qgslegendpatchshape.h"
 
 class QgsSymbol;
 class QgsSymbolLayer;
@@ -163,9 +163,9 @@ class CORE_EXPORT QgsStyle : public QObject
   public:
 
     /**
-     * Constructor for QgsStyle.
+     * Constructor for QgsStyle, with the specified \a parent object.
      */
-    QgsStyle();
+    QgsStyle( QObject *parent SIP_TRANSFERTHIS = nullptr );
     ~QgsStyle() override;
 
     /**
@@ -187,6 +187,55 @@ class CORE_EXPORT QgsStyle : public QObject
       Symbol3DEntity, //!< 3D symbol entity (since QGIS 3.14)
     };
 
+    /**
+     * Returns the name of the style.
+     *
+     * \see setName()
+     * \since QGIS 3.26
+     */
+    QString name() const;
+
+    /**
+     * Sets the \a name of the style.
+     *
+     * \see name()
+     * \since QGIS 3.26
+     */
+    void setName( const QString &name );
+
+    /**
+     * Returns TRUE if the style is initialized and ready for use.
+     *
+     * Most instances of QgsStyle will already be initialized. However, if the
+     * style is the QgsStyle::defaultStyle() object it may have been created using
+     * lazy initialization and will return FALSE until it is initialized().
+     *
+     * \since QGIS 3.36
+     */
+    bool isInitialized() const { return mInitialized; }
+
+    /**
+     * Returns TRUE if the style is considered a read-only library.
+     *
+     * \note This flag is used to control GUI operations, and does not prevent calling functions
+     * which mutate the style directly via the API.
+     *
+     * \see setReadOnly()
+     * \since QGIS 3.26
+     */
+    bool isReadOnly() const;
+
+    /**
+     * Sets whether the style is considered a read-only library.
+     *
+     * \note This flag is used to control GUI operations, and does not prevent calling functions
+     * which mutate the style directly via the API.
+     *
+     * \see isReadOnly()
+     * \since QGIS 3.26
+     */
+    void setReadOnly( bool readOnly );
+
     /**
      * Adds an \a entity to the style, with the specified \a name. Ownership is not transferred.
      *
@@ -307,7 +356,6 @@ class CORE_EXPORT QgsStyle : public QObject
      * Returns a list of all tags in the style database
      *
      * \see addTag()
-     * \since QGIS 2.16
      */
     QStringList tags() const;
 
@@ -410,16 +458,16 @@ class CORE_EXPORT QgsStyle : public QObject
      *
      * \since QGIS 3.16
      */
-    QList< QgsWkbTypes::GeometryType > symbol3DCompatibleGeometryTypes( const QString &name ) const;
+    QList< Qgis::GeometryType > symbol3DCompatibleGeometryTypes( const QString &name ) const;
 
     /**
      * Returns the layer geometry type corresponding to the label settings
-     * with the specified \a name, or QgsWkbTypes::UnknownGeometry
+     * with the specified \a name, or Qgis::GeometryType::Unknown
      * if matching label settings are not present.
      *
      * \since QGIS 3.10
      */
-    QgsWkbTypes::GeometryType labelSettingsLayerType( const QString &name ) const;
+    Qgis::GeometryType labelSettingsLayerType( const QString &name ) const;
 
     /**
      * Returns count of label settings in the style.
@@ -441,8 +489,15 @@ class CORE_EXPORT QgsStyle : public QObject
      */
     int labelSettingsId( const QString &name );
 
-    //! Returns default application-wide style
-    static QgsStyle *defaultStyle();
+    /**
+     * Returns the default application-wide style.
+     *
+     * Since QGIS 3.36, the \a initialize argument can be set to FALSE to temporarily
+     * defer the actual loading of the style's objects until they are first requested.
+     * This lazy-initialization can substantially improve application startup times,
+     * especially for standalone applications which do not utilize styles.
+     */
+    static QgsStyle *defaultStyle( bool initialize = true );
 
     //! Deletes the default style. Only to be used by QgsApplication::exitQgis()
     static void cleanDefaultStyle() SIP_SKIP;
@@ -739,6 +794,13 @@ class CORE_EXPORT QgsStyle : public QObject
      */
     QgsTextFormat defaultTextFormat( QgsStyle::TextFormatContext context = QgsStyle::TextFormatContext::Labeling ) const;
 
+    /**
+     * Returns the default text format to use for new text based objects for the specified \a project, in the specified \a context.
+     *
+     * \since QGIS 3.26
+     */
+    static QgsTextFormat defaultTextFormatForProject( QgsProject *project,  QgsStyle::TextFormatContext context = QgsStyle::TextFormatContext::Labeling );
+
     /**
      * Adds a 3d \a symbol to the database.
      *
@@ -771,7 +833,6 @@ class CORE_EXPORT QgsStyle : public QObject
      *  This function creates a new on-disk permanent style database.
      *  \returns returns the success state of the database creation
      *  \see createMemoryDatabase()
-     *  \since QGIS 3.0
      */
     bool createDatabase( const QString &filename );
 
@@ -781,7 +842,6 @@ class CORE_EXPORT QgsStyle : public QObject
      *  This function is used to create a temporary style database in case a permanent on-disk database is not needed.
      *  \returns returns the success state of the temporary memory database creation
      *  \see createDatabase()
-     *  \since QGIS 3.0
      */
     bool createMemoryDatabase();
 
@@ -789,10 +849,8 @@ class CORE_EXPORT QgsStyle : public QObject
      * Creates tables structure for new database
      *
      *  This function is used to create the tables structure in a newly-created database.
-     *  \returns returns the success state of the temporary memory database creation
      *  \see createDatabase()
      *  \see createMemoryDatabase()
-     *  \since QGIS 3.0
      */
     void createTables();
 
@@ -801,18 +859,59 @@ class CORE_EXPORT QgsStyle : public QObject
      *
      *  This function will load an on-disk database and populate styles.
      *  \param filename location of the database to load styles from
-     *  \returns returns the success state of the database being loaded
+     *  \returns TRUE if the database was successfully loaded. If FALSE is
+     *  returned then a detailed error message can be retrieved via errorString().
+     *
+     *  \see errorString()
      */
     bool load( const QString &filename );
 
-    //! Saves style into a file (will use current filename if empty string is passed)
-    bool save( QString filename = QString() );
+    /**
+     * Saves style into a file.
+     *
+     * The current fileName() will be used if no explicit \a filename is specified.
+     *
+     *  \returns TRUE if the style was successfully saved. If FALSE is
+     *  returned then a detailed error message can be retrieved via errorString().
+     *
+     * \see fileName()
+     * \see load()
+     * \see errorString()
+     *
+     * \deprecated This function has no effect.
+     */
+    Q_DECL_DEPRECATED bool save( const QString &filename = QString() ) SIP_DEPRECATED;
 
-    //! Returns last error from load/save operation
-    QString errorString() { return mErrorString; }
+    /**
+     * Returns the last error from a load() operation.
+     *
+     * \see load()
+     */
+    QString errorString() const { return mErrorString; }
 
-    //! Returns current file name of the style
-    QString fileName() { return mFileName; }
+    /**
+     * Returns the current file name of the style database.
+     *
+     * The filename will always represent the actual source of the style - e.g. the .db file
+     * for styles associated with a database, or the original source .xml file for styles
+     * directly loaded from a .xml export.
+     *
+     * \see setFileName()
+     */
+    QString fileName() const { return mFileName; }
+
+    /**
+     * Sets the current file name of the style database.
+     *
+     * The filename should always represent the actual source of the style - e.g. the .db file
+     * for styles associated with a database, or the original source .xml file for styles
+     * directly loaded from a .xml export.
+     *
+     * Calling load() automatically sets the filename to the .db file path.
+     *
+     * \since QGIS 3.26
+     */
+    void setFileName( const QString &filename );
 
     /**
      * Returns the names of the symbols which have a matching 'substring' in its definition
@@ -886,8 +985,42 @@ class CORE_EXPORT QgsStyle : public QObject
      */
     static bool isXmlStyleFile( const QString &path );
 
+  public slots:
+#ifndef SIP_RUN
+
+    /**
+     * Triggers emission of the rebuildIconPreviews() signal.
+     *
+     * \note Not available in Python bindings.
+     *
+     * \since QGIS 3.26
+     */
+    void triggerIconRebuild();
+#endif
+
   signals:
 
+    /**
+     * Emitted when the style database has been fully initialized.
+     *
+     * This signals is only emitted by the QgsStyle::defaultStyle() instance,
+     * and only when the defaultStyle() has been lazily initialized.
+     *
+     * \since QGIS 3.36
+     */
+    void initialized();
+
+    /**
+     * Emitted just before the style object is destroyed.
+     *
+     * Emitted in the destructor when the style is about to be deleted,
+     * but it is still in a perfectly valid state: the last chance for
+     * other pieces of code for some cleanup if they use the style.
+     *
+     * \since QGIS 3.26
+     */
+    void aboutToBeDestroyed();
+
     /**
      * Emitted every time a new symbol has been added to the database.
      * Emitted whenever a symbol has been added to the style and the database
@@ -1005,7 +1138,6 @@ class CORE_EXPORT QgsStyle : public QObject
      */
     void rampChanged( const QString &name );
 
-
     /**
      * Emitted whenever a text format has been renamed from \a oldName to \a newName
      * \see symbolRenamed()
@@ -1076,8 +1208,19 @@ class CORE_EXPORT QgsStyle : public QObject
      */
     void labelSettingsChanged( const QString &name );
 
+    /**
+     * Emitted whenever icon previews for entities in the style must be rebuilt.
+     *
+     * \since QGIS 3.26
+     */
+    void rebuildIconPreviews();
+
   private:
 
+    bool mInitialized = true;
+    QString mName;
+    bool mReadOnly = false;
+
     QgsSymbolMap mSymbols;
     QgsVectorColorRampMap mColorRamps;
     QgsTextFormatMap mTextFormats;
@@ -1105,6 +1248,13 @@ class CORE_EXPORT QgsStyle : public QObject
 
     static QgsStyle *sDefaultStyle;
 
+    /**
+     * Loads default style database contents from the specified \a filename.
+     *
+     * \warning Must only be called on defaultStyle() instance!
+     */
+    void initializeDefaultStyle( const QString &filename );
+
     //! Convenience function to open the DB and return a sqlite3 object
     bool openDatabase( const QString &filename );
 
@@ -1137,7 +1287,10 @@ class CORE_EXPORT QgsStyle : public QObject
 
     void clearCachedTags( StyleEntity type, const QString &name );
 
-
+    /**
+     * Returns TRUE if style metadata table did not exist and was newly created.
+     */
+    bool createStyleMetadataTableIfNeeded();
     void upgradeIfRequired();
 
     /**
