@@ -28,6 +28,7 @@
 
 #include <QStandardItemModel>
 #include <QDialogButtonBox>
+#include <QPointer>
 #include "qgis_gui.h"
 
 class QgsStyle;
@@ -104,6 +105,16 @@ class GUI_EXPORT QgsSymbolSelectorWidget: public QgsPanelWidget, private Ui::Qgs
      */
     QgsSymbolSelectorWidget( QgsSymbol *symbol, QgsStyle *style, QgsVectorLayer *vl, QWidget *parent SIP_TRANSFERTHIS = nullptr );
 
+    // TODO QGIS 4.0 -- remove when normal constructor takes ownership
+
+    /**
+     * Creates a QgsSymbolSelectorWidget which takes ownership of a symbol and maintains
+     * the ownership for the life of the widget.
+     *
+     * \note Not available in Python bindings.
+    */
+    static QgsSymbolSelectorWidget *createWidgetWithSymbolOwnership( std::unique_ptr< QgsSymbol > symbol, QgsStyle *style, QgsVectorLayer *vl, QWidget *parent SIP_TRANSFERTHIS = nullptr ) SIP_SKIP;
+
     //! Returns menu for "advanced" button - create it if doesn't exist and show the advanced button
     QMenu *advancedMenu();
 
@@ -111,14 +122,12 @@ class GUI_EXPORT QgsSymbolSelectorWidget: public QgsPanelWidget, private Ui::Qgs
      * Sets the context in which the symbol widget is shown, e.g., the associated map canvas and expression contexts.
      * \param context symbol widget context
      * \see context()
-     * \since QGIS 3.0
      */
     void setContext( const QgsSymbolWidgetContext &context );
 
     /**
      * Returns the context in which the symbol widget is shown, e.g., the associated map canvas and expression contexts.
      * \see setContext()
-     * \since QGIS 3.0
      */
     QgsSymbolWidgetContext context() const;
 
@@ -167,7 +176,6 @@ class GUI_EXPORT QgsSymbolSelectorWidget: public QgsPanelWidget, private Ui::Qgs
 
     /**
      * Duplicates the current symbol layer and places the duplicated layer above the current symbol layer
-     * \since QGIS 2.14
      */
     void duplicateLayer();
 
@@ -233,6 +241,8 @@ class GUI_EXPORT QgsSymbolSelectorWidget: public QgsPanelWidget, private Ui::Qgs
      */
     void updateLockButton();
 
+    void updateLockButtonIcon();
+
     SymbolLayerItem *currentLayerItem();
 
     /**
@@ -255,8 +265,11 @@ class GUI_EXPORT QgsSymbolSelectorWidget: public QgsPanelWidget, private Ui::Qgs
 
     QgsStyle *mStyle = nullptr;
     QgsSymbol *mSymbol = nullptr;
+    std::unique_ptr< QgsSymbol > mOwnedSymbol;
     QMenu *mAdvancedMenu = nullptr;
-    QgsVectorLayer *mVectorLayer = nullptr;
+    QAction *mLockColorAction = nullptr;
+    QAction *mLockSelectionColorAction = nullptr;
+    QPointer< QgsVectorLayer > mVectorLayer;
 
     QStandardItemModel *mSymbolLayersModel = nullptr;
     QWidget *mPresentWidget = nullptr;
@@ -297,14 +310,12 @@ class GUI_EXPORT QgsSymbolSelectorDialog : public QDialog
      * Sets the context in which the symbol widget is shown, e.g., the associated map canvas and expression contexts.
      * \param context symbol widget context
      * \see context()
-     * \since QGIS 3.0
      */
     void setContext( const QgsSymbolWidgetContext &context );
 
     /**
      * Returns the context in which the symbol widget is shown, e.g., the associated map canvas and expression contexts.
      * \see setContext()
-     * \since QGIS 3.0
      */
     QgsSymbolWidgetContext context() const;
 
@@ -339,7 +350,6 @@ class GUI_EXPORT QgsSymbolSelectorDialog : public QDialog
 
     /**
      * Duplicates the current symbol layer and places the duplicated layer above the current symbol layer
-     * \since QGIS 2.14
      */
     void duplicateLayer();
 
