@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 /***************************************************************************
 Name                 : DB Manager
@@ -22,13 +20,16 @@ The content of this file is based on
  ***************************************************************************/
 """
 
-from PyQt4.QtCore import Qt, SIGNAL
-from PyQt4.QtGui import QDialog, QMessageBox, QApplication
+from qgis.PyQt import uic
+from qgis.PyQt.QtCore import Qt
+from qgis.PyQt.QtWidgets import QDialog, QMessageBox, QApplication
+from qgis.utils import OverrideCursor
 
 from .db_plugins.plugin import DbError
 from .dlg_db_error import DlgDbError
+from .gui_utils import GuiUtils
 
-from .ui.ui_DlgAddGeometryColumn import Ui_DbManagerDlgAddGeometryColumn as Ui_Dialog
+Ui_Dialog, _ = uic.loadUiType(GuiUtils.get_ui_file_path('DlgAddGeometryColumn.ui'))
 
 
 class DlgAddGeometryColumn(QDialog, Ui_Dialog):
@@ -41,12 +42,12 @@ class DlgAddGeometryColumn(QDialog, Ui_Dialog):
         self.db = self.table.database() if self.table and self.table.database() else db
         self.setupUi(self)
 
-        self.connect(self.buttonBox, SIGNAL("accepted()"), self.createGeomColumn)
+        self.buttonBox.accepted.connect(self.createGeomColumn)
 
     def createGeomColumn(self):
         """ first check whether everything's fine """
         if self.editName.text() == "":
-            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("field name must not be empty"))
+            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("Field name must not be empty."))
             return
 
         name = self.editName.text()
@@ -59,13 +60,11 @@ class DlgAddGeometryColumn(QDialog, Ui_Dialog):
         createSpatialIndex = False
 
         # now create the geometry column
-        QApplication.setOverrideCursor(Qt.WaitCursor)
-        try:
-            self.table.addGeometryColumn(name, geom_type, srid, dim, createSpatialIndex)
-        except DbError, e:
-            DlgDbError.showError(e, self)
-            return
-        finally:
-            QApplication.restoreOverrideCursor()
+        with OverrideCursor(Qt.CursorShape.WaitCursor):
+            try:
+                self.table.addGeometryColumn(name, geom_type, srid, dim, createSpatialIndex)
+            except DbError as e:
+                DlgDbError.showError(e, self)
+                return
 
         self.accept()
