@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 /***************************************************************************
 Name                 : DB Manager
@@ -34,7 +32,7 @@ from .db_plugins.plugin import Table
 class LayerPreview(QgsMapCanvas):
 
     def __init__(self, parent=None):
-        super(LayerPreview, self).__init__(parent)
+        super().__init__(parent)
         self.parent = parent
         self.setCanvasColor(QColor(255, 255, 255))
 
@@ -91,7 +89,7 @@ class LayerPreview(QgsMapCanvas):
 
     def _loadTablePreview(self, table, limit=False):
         """ if has geometry column load to map canvas """
-        with OverrideCursor(Qt.WaitCursor):
+        with OverrideCursor(Qt.CursorShape.WaitCursor):
             self.freeze()
             vl = None
 
@@ -103,7 +101,7 @@ class LayerPreview(QgsMapCanvas):
                         self.parent.tabs.setCurrentWidget(self.parent.info)
                         self.parent.infoBar.pushMessage(
                             QApplication.translate("DBManagerPlugin", "Unable to find a valid unique field"),
-                            Qgis.Warning, self.parent.iface.messageTimeout())
+                            Qgis.MessageLevel.Warning, self.parent.iface.messageTimeout())
                         return
 
                     uri = table.database().uri()
