@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     ProcessingPlugin.py
@@ -24,34 +22,61 @@ __copyright__ = '(C) 2012, Victor Olaya'
 import shutil
 import os
 import sys
+from typing import List
 from functools import partial
 
 from qgis.core import (QgsApplication,
                        QgsProcessingUtils,
                        QgsProcessingModelAlgorithm,
+                       QgsProcessingAlgorithm,
                        QgsDataItemProvider,
                        QgsDataProvider,
                        QgsDataItem,
                        QgsMapLayerType,
-                       QgsMimeDataUtils)
-from qgis.gui import (QgsOptionsWidgetFactory,
-                      QgsCustomDropHandler)
-from qgis.PyQt.QtCore import Qt, QCoreApplication, QDir, QFileInfo
-from qgis.PyQt.QtWidgets import QMenu, QAction
-from qgis.PyQt.QtGui import QIcon, QKeySequence
+                       QgsMimeDataUtils,
+                       QgsSettings)
+from qgis.gui import (QgsGui,
+                      QgsOptionsWidgetFactory,
+                      QgsCustomDropHandler,
+                      QgsProcessingHistoryDialog)
+from qgis.PyQt.QtCore import (
+    QObject,
+    Qt,
+    QItemSelectionModel,
+    QCoreApplication,
+    QDir,
+    QFileInfo,
+    pyqtSlot,
+    QMetaObject
+)
+from qgis.PyQt.QtWidgets import (
+    QWidget,
+    QMenu,
+    QAction
+)
+from qgis.PyQt.QtGui import (
+    QIcon,
+    QKeySequence
+)
 from qgis.utils import iface
 
 from processing.core.Processing import Processing
-from processing.gui.AlgorithmDialog import AlgorithmDialog
 from processing.gui.ProcessingToolbox import ProcessingToolbox
-from processing.gui.HistoryDialog import HistoryDialog
 from processing.gui.ConfigDialog import ConfigOptionsPage
 from processing.gui.ResultsDock import ResultsDock
+from processing.gui.MessageDialog import MessageDialog
+from processing.gui.MessageBarProgress import MessageBarProgress
 from processing.gui.AlgorithmLocatorFilter import (AlgorithmLocatorFilter,
                                                    InPlaceAlgorithmLocatorFilter)
+from processing.gui.Postprocessing import handleAlgorithmResults
+from processing.gui.AlgorithmExecutor import execute, execute_in_place
+from processing.gui.AlgorithmDialog import AlgorithmDialog
+from processing.gui.BatchAlgorithmDialog import BatchAlgorithmDialog
+from processing.gui import TestTools
 from processing.modeler.ModelerDialog import ModelerDialog
 from processing.tools.system import tempHelpFolder
-from processing.gui.menus import removeMenus, initializeMenus, createMenus
+from processing.tools import dataobjects
+from processing.gui.menus import removeMenus, initializeMenus, createMenus, createButtons, removeButtons
 from processing.core.ProcessingResults import resultsList
 
 pluginPath = os.path.dirname(__file__)
@@ -85,6 +110,9 @@ class ProcessingDropHandler(QgsCustomDropHandler):
         alg.setProvider(QgsApplication.processingRegistry().providerById('model'))
         dlg = AlgorithmDialog(alg, parent=iface.mainWindow())
         dlg.show()
+        # do NOT remove!!!! if you do then sip forgets the python subclass of AlgorithmDialog and you get a broken
+        # dialog
+        dlg.exec()
         return True
 
     def customUriProviderKey(self):
@@ -98,8 +126,8 @@ class ProcessingDropHandler(QgsCustomDropHandler):
 class ProcessingModelItem(QgsDataItem):
 
     def __init__(self, parent, name, path):
-        super(ProcessingModelItem, self).__init__(QgsDataItem.Custom, parent, name, path)
-        self.setState(QgsDataItem.Populated)  # no children
+        super().__init__(QgsDataItem.Type.Custom, parent, name, path)
+        self.setState(QgsDataItem.State.Populated)  # no children
         self.setIconName(":/images/themes/default/processingModel.svg")
         self.setToolTip(QDir.toNativeSeparators(path))
 
@@ -122,7 +150,7 @@ class ProcessingModelItem(QgsDataItem):
         ProcessingDropHandler.runAlg(self.path())
 
     def editModel(self):
-        dlg = ModelerDialog()
+        dlg = ModelerDialog.create()
         dlg.loadModel(self.path())
         dlg.show()
 
@@ -137,13 +165,13 @@ class ProcessingModelItem(QgsDataItem):
 class ProcessingDataItemProvider(QgsDataItemProvider):
 
     def __init__(self):
-        super(ProcessingDataItemProvider, self).__init__()
+        super().__init__()
 
     def name(self):
         return 'processing'
 
     def capabilities(self):
-        return QgsDataProvider.File
+        return QgsDataProvider.DataCapability.File
 
     def createDataItem(self, path, parentItem):
         file_info = QFileInfo(path)
@@ -155,9 +183,10 @@ class ProcessingDataItemProvider(QgsDataItemProvider):
         return None
 
 
-class ProcessingPlugin:
+class ProcessingPlugin(QObject):
 
     def __init__(self, iface):
+        super().__init__()
         self.iface = iface
         self.options_factory = None
         self.drop_handler = None
@@ -165,6 +194,7 @@ class ProcessingPlugin:
         self.locator_filter = None
         self.edit_features_locator_filter = None
         self.initialized = False
+        self._gui_connections: List[QMetaObject.Connection] = []
         self.initProcessing()
 
     def initProcessing(self):
@@ -172,7 +202,18 @@ class ProcessingPlugin:
             self.initialized = True
             Processing.initialize()
 
+    def finalizeStartup(self):
+        Processing.perform_deferred_model_initialization()
+
     def initGui(self):
+        # port old log, ONCE ONLY!
+        settings = QgsSettings()
+        if not settings.value("/Processing/hasPortedOldLog", False, bool):
+            processing_history_provider = QgsGui.historyProviderRegistry().providerById('processing')
+            if processing_history_provider:
+                processing_history_provider.portOldLog()
+                settings.setValue("/Processing/hasPortedOldLog", True)
+
         self.options_factory = ProcessingOptionsFactory()
         self.options_factory.setTitle(self.tr('Processing'))
         iface.registerOptionsWidgetFactory(self.options_factory)
@@ -183,17 +224,28 @@ class ProcessingPlugin:
         self.locator_filter = AlgorithmLocatorFilter()
         iface.registerLocatorFilter(self.locator_filter)
         # Invalidate the locator filter for in-place when active layer changes
-        iface.currentLayerChanged.connect(lambda _: self.iface.invalidateLocatorResults())
+        self._gui_connections.append(
+            iface.currentLayerChanged.connect(lambda _: self.iface.invalidateLocatorResults())
+        )
         self.edit_features_locator_filter = InPlaceAlgorithmLocatorFilter()
         iface.registerLocatorFilter(self.edit_features_locator_filter)
 
+        QgsGui.historyProviderRegistry().providerById('processing').executePython.connect(
+            self._execute_history_commands
+        )
+        QgsGui.historyProviderRegistry().providerById('processing').createTest.connect(
+            self.create_test
+        )
+
         self.toolbox = ProcessingToolbox()
-        self.iface.addDockWidget(Qt.RightDockWidgetArea, self.toolbox)
+        self.iface.addDockWidget(Qt.DockWidgetArea.RightDockWidgetArea, self.toolbox)
         self.toolbox.hide()
         self.toolbox.visibilityChanged.connect(self.toolboxVisibilityChanged)
 
+        self.toolbox.executeWithGui.connect(self.executeAlgorithm)
+
         self.resultsDock = ResultsDock()
-        self.iface.addDockWidget(Qt.RightDockWidgetArea, self.resultsDock)
+        self.iface.addDockWidget(Qt.DockWidgetArea.RightDockWidgetArea, self.resultsDock)
         self.resultsDock.hide()
 
         self.menu = QMenu(self.iface.mainWindow().menuBar())
@@ -206,18 +258,18 @@ class ProcessingPlugin:
         self.toolboxAction.setIcon(
             QgsApplication.getThemeIcon("/processingAlgorithm.svg"))
         self.iface.registerMainWindowAction(self.toolboxAction,
-                                            QKeySequence('Ctrl+Alt+T').toString(QKeySequence.NativeText))
+                                            QKeySequence('Ctrl+Alt+T').toString(QKeySequence.SequenceFormat.NativeText))
         self.toolboxAction.toggled.connect(self.openToolbox)
         self.iface.attributesToolBar().insertAction(self.iface.actionOpenStatisticalSummary(), self.toolboxAction)
         self.menu.addAction(self.toolboxAction)
 
         self.modelerAction = QAction(
             QgsApplication.getThemeIcon("/processingModel.svg"),
-            QCoreApplication.translate('ProcessingPlugin', '&Graphical Modeler…'), self.iface.mainWindow())
+            QCoreApplication.translate('ProcessingPlugin', '&Model Designer…'), self.iface.mainWindow())
         self.modelerAction.setObjectName('modelerAction')
         self.modelerAction.triggered.connect(self.openModeler)
         self.iface.registerMainWindowAction(self.modelerAction,
-                                            QKeySequence('Ctrl+Alt+G').toString(QKeySequence.NativeText))
+                                            QKeySequence('Ctrl+Alt+G').toString(QKeySequence.SequenceFormat.NativeText))
         self.menu.addAction(self.modelerAction)
 
         self.historyAction = QAction(
@@ -226,7 +278,7 @@ class ProcessingPlugin:
         self.historyAction.setObjectName('historyAction')
         self.historyAction.triggered.connect(self.openHistory)
         self.iface.registerMainWindowAction(self.historyAction,
-                                            QKeySequence('Ctrl+Alt+H').toString(QKeySequence.NativeText))
+                                            QKeySequence('Ctrl+Alt+H').toString(QKeySequence.SequenceFormat.NativeText))
         self.menu.addAction(self.historyAction)
         self.toolbox.processingToolbar.addAction(self.historyAction)
 
@@ -236,7 +288,7 @@ class ProcessingPlugin:
         self.resultsAction.setObjectName('resultsViewer')
         self.resultsAction.setCheckable(True)
         self.iface.registerMainWindowAction(self.resultsAction,
-                                            QKeySequence('Ctrl+Alt+R').toString(QKeySequence.NativeText))
+                                            QKeySequence('Ctrl+Alt+R').toString(QKeySequence.SequenceFormat.NativeText))
 
         self.menu.addAction(self.resultsAction)
         self.toolbox.processingToolbar.addAction(self.resultsAction)
@@ -271,13 +323,133 @@ class ProcessingPlugin:
 
         initializeMenus()
         createMenus()
+        createButtons()
 
         # In-place editing button state sync
-        self.iface.currentLayerChanged.connect(self.sync_in_place_button_state)
-        self.iface.mapCanvas().selectionChanged.connect(self.sync_in_place_button_state)
-        self.iface.actionToggleEditing().triggered.connect(partial(self.sync_in_place_button_state, None))
+
+        # we need to explicitly store and disconnect these connections
+        # on plugin unload -- they aren't cleaned up automatically (see
+        # https://github.com/qgis/QGIS/issues/53455)
+        self._gui_connections.append(
+            self.iface.currentLayerChanged.connect(self.sync_in_place_button_state)
+        )
+        self._gui_connections.append(
+            self.iface.mapCanvas().selectionChanged.connect(self.sync_in_place_button_state)
+        )
+        self._gui_connections.append(
+            self.iface.actionToggleEditing().triggered.connect(partial(self.sync_in_place_button_state, None))
+        )
         self.sync_in_place_button_state()
 
+        # Sync project models
+        self.projectModelsMenu = None
+        self.projectMenuAction = None
+        self.projectMenuSeparator = None
+
+        self.projectProvider = QgsApplication.instance().processingRegistry().providerById("project")
+        self._gui_connections.append(
+            self.projectProvider.algorithmsLoaded.connect(self.updateProjectModelMenu)
+        )
+
+    def updateProjectModelMenu(self):
+        """Add projects models to menu"""
+
+        if self.projectMenuAction is None:
+            self.projectModelsMenu = QMenu(self.tr("Models"))
+            self.projectMenuAction = self.iface.projectMenu().insertMenu(self.iface.projectMenu().children()[-1], self.projectModelsMenu)
+            self.projectMenuAction.setParent(self.projectModelsMenu)
+            self.iface.projectMenu().insertSeparator(self.projectMenuAction)
+
+        self.projectModelsMenu.clear()
+
+        for model in self.projectProvider.algorithms():
+            modelSubMenu = self.projectModelsMenu.addMenu(model.name())
+            modelSubMenu.setParent(self.projectModelsMenu)
+            action = QAction(self.tr("Execute…"), modelSubMenu)
+            action.triggered.connect(partial(self.executeAlgorithm, model.id(), self.projectModelsMenu, self.toolbox.in_place_mode))
+            modelSubMenu.addAction(action)
+            if model.flags() & QgsProcessingAlgorithm.Flag.FlagSupportsBatch:
+                action = QAction(self.tr("Execute as Batch Process…"), modelSubMenu)
+                modelSubMenu.addAction(action)
+                action.triggered.connect(partial(self.executeAlgorithm, model.id(), self.projectModelsMenu, self.toolbox.in_place_mode, True))
+
+    @pyqtSlot(str, QWidget, bool, bool)
+    def executeAlgorithm(self, alg_id, parent, in_place=False, as_batch=False):
+        """Executes a project model with GUI interaction if needed.
+
+        :param alg_id: algorithm id
+        :type alg_id: string
+        :param parent: parent widget
+        :type parent: QWidget
+        :param in_place: in place flag, defaults to False
+        :type in_place: bool, optional
+        :param as_batch: execute as batch flag, defaults to False
+        :type as_batch: bool, optional
+        """
+
+        config = {}
+        if in_place:
+            config['IN_PLACE'] = True
+
+        alg = QgsApplication.instance().processingRegistry().createAlgorithmById(alg_id, config)
+
+        if alg is not None:
+
+            ok, message = alg.canExecute()
+            if not ok:
+                dlg = MessageDialog()
+                dlg.setTitle(self.tr('Error executing algorithm'))
+                dlg.setMessage(
+                    self.tr('<h3>This algorithm cannot '
+                            'be run :-( </h3>\n{0}').format(message))
+                dlg.exec()
+                return
+
+            if as_batch:
+                dlg = BatchAlgorithmDialog(alg, iface.mainWindow())
+                dlg.show()
+                dlg.exec()
+            else:
+                in_place_input_parameter_name = 'INPUT'
+                if hasattr(alg, 'inputParameterName'):
+                    in_place_input_parameter_name = alg.inputParameterName()
+
+                if in_place and not [d for d in alg.parameterDefinitions() if d.name() not in (in_place_input_parameter_name, 'OUTPUT')]:
+                    parameters = {}
+                    feedback = MessageBarProgress(algname=alg.displayName())
+                    ok, results = execute_in_place(alg, parameters, feedback=feedback)
+                    if ok:
+                        iface.messageBar().pushSuccess('', self.tr('{algname} completed. %n feature(s) processed.', n=results['__count']).format(algname=alg.displayName()))
+                    feedback.close()
+                    # MessageBarProgress handles errors
+                    return
+
+                if alg.countVisibleParameters() > 0:
+                    dlg = alg.createCustomParametersWidget(parent)
+
+                    if not dlg:
+                        dlg = AlgorithmDialog(alg, in_place, iface.mainWindow())
+                    canvas = iface.mapCanvas()
+                    prevMapTool = canvas.mapTool()
+                    dlg.show()
+                    dlg.exec()
+                    if canvas.mapTool() != prevMapTool:
+                        try:
+                            canvas.mapTool().reset()
+                        except Exception:
+                            pass
+                        try:
+                            canvas.setMapTool(prevMapTool)
+                        except RuntimeError:
+                            pass
+                else:
+                    feedback = MessageBarProgress(algname=alg.displayName())
+                    context = dataobjects.createContext(feedback)
+                    parameters = {}
+                    ret, results = execute(alg, parameters, context, feedback)
+                    handleAlgorithmResults(alg, context, feedback)
+                    feedback.close()
+
     def sync_in_place_button_state(self, layer=None):
         """Synchronise the button state with layer state"""
 
@@ -296,6 +468,9 @@ class ProcessingPlugin:
         self.iface.showOptionsDialog(self.iface.mainWindow(), currentPage='processingOptions')
 
     def unload(self):
+        for connection in self._gui_connections:
+            self.disconnect(connection)
+        self._gui_connections = []
         self.toolbox.setVisible(False)
         self.iface.removeDockWidget(self.toolbox)
         self.iface.attributesToolBar().removeAction(self.toolboxAction)
@@ -322,7 +497,23 @@ class ProcessingPlugin:
         self.iface.unregisterCustomDropHandler(self.drop_handler)
         QgsApplication.dataItemProviderRegistry().removeProvider(self.item_provider)
 
+        removeButtons()
         removeMenus()
+
+        if self.projectMenuAction is not None:
+            self.iface.projectMenu().removeAction(self.projectMenuAction)
+            self.projectMenuAction = None
+        if self.projectMenuSeparator is not None:
+            self.iface.projectMenu().removeAction(self.projectMenuSeparator)
+            self.projectMenuSeparator = None
+
+        QgsGui.historyProviderRegistry().providerById('processing').executePython.disconnect(
+            self._execute_history_commands
+        )
+        QgsGui.historyProviderRegistry().providerById('processing').createTest.disconnect(
+            self.create_test
+        )
+
         Processing.deinitialize()
 
     def openToolbox(self, show):
@@ -332,7 +523,7 @@ class ProcessingPlugin:
         self.toolboxAction.setChecked(visible)
 
     def openModeler(self):
-        dlg = ModelerDialog()
+        dlg = ModelerDialog.create()
         dlg.update_model.connect(self.updateModel)
         dlg.show()
 
@@ -347,11 +538,24 @@ class ProcessingPlugin:
             self.resultsDock.show()
 
     def openHistory(self):
-        dlg = HistoryDialog()
-        dlg.exec_()
+        dlg = QgsProcessingHistoryDialog(self.iface.mainWindow())
+        dlg.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
+        dlg.show()
 
-    def tr(self, message):
-        return QCoreApplication.translate('ProcessingPlugin', message)
+    def tr(self, message, disambiguation=None, n=-1):
+        return QCoreApplication.translate('ProcessingPlugin', message, disambiguation=disambiguation, n=n)
 
     def editSelected(self, enabled):
         self.toolbox.set_in_place_edit_mode(enabled)
+
+    def _execute_history_commands(self, commands: str):
+        """
+        Executes Python commands from the history provider
+        """
+        exec(commands)
+
+    def create_test(self, command: str):
+        """
+        Starts the test creation process given a processing algorithm run command
+        """
+        TestTools.createTest(command)
