@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     GdalAlgorithm.py
@@ -23,6 +21,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 import os
 import re
+from typing import Dict
 
 from qgis.PyQt.QtCore import QUrl, QCoreApplication
 
@@ -32,10 +31,14 @@ from qgis.core import (QgsApplication,
                        QgsProcessingAlgorithm,
                        QgsProcessingContext,
                        QgsProcessingFeedback,
-                       QgsProviderRegistry)
+                       QgsProviderRegistry,
+                       QgsDataSourceUri)
 
 from processing.algs.gdal.GdalAlgorithmDialog import GdalAlgorithmDialog
-from processing.algs.gdal.GdalUtils import GdalUtils
+from processing.algs.gdal.GdalUtils import (
+    GdalUtils,
+    GdalConnectionDetails
+)
 
 pluginPath = os.path.normpath(os.path.join(
     os.path.split(os.path.dirname(__file__))[0], os.pardir))
@@ -62,16 +65,17 @@ class GdalAlgorithm(QgsProcessingAlgorithm):
     def createCustomParametersWidget(self, parent):
         return GdalAlgorithmDialog(self, parent=parent)
 
-    def flags(self):
-        return QgsProcessingAlgorithm.FlagSupportsBatch # cannot cancel!
-
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
         return None
 
-    def getOgrCompatibleSource(self, parameter_name, parameters, context, feedback, executing):
+    def getOgrCompatibleSource(self,
+                               parameter_name: str,
+                               parameters: Dict,
+                               context: QgsProcessingContext,
+                               feedback: QgsProcessingFeedback,
+                               executing: bool) -> GdalConnectionDetails:
         """
-        Interprets a parameter as an OGR compatible source and layer name
-        :param executing:
+        Interprets a parameter as a GDAL connection details
         """
         if not executing and parameter_name in parameters and isinstance(parameters[parameter_name], QgsProcessingFeatureSourceDefinition):
             # if not executing, then we throw away all 'selected features only' settings
@@ -80,24 +84,30 @@ class GdalAlgorithm(QgsProcessingAlgorithm):
             parameters = {parameter_name: parameters[parameter_name].source}
 
         input_layer = self.parameterAsVectorLayer(parameters, parameter_name, context)
-        ogr_data_path = None
-        ogr_layer_name = None
-        if input_layer is None or input_layer.dataProvider().name() == 'memory':
+        if input_layer is None or input_layer.providerType() == 'memory':
             if executing:
                 # parameter is not a vector layer - try to convert to a source compatible with OGR
                 # and extract selection if required
                 ogr_data_path = self.parameterAsCompatibleSourceLayerPath(parameters, parameter_name, context,
                                                                           QgsVectorFileWriter.supportedFormatExtensions(),
+                                                                          QgsVectorFileWriter.supportedFormatExtensions()[0],
                                                                           feedback=feedback)
-                ogr_layer_name = GdalUtils.ogrLayerName(ogr_data_path)
+
+                return GdalConnectionDetails(
+                    connection_string=ogr_data_path,
+                    layer_name=GdalUtils.ogrLayerName(ogr_data_path)
+                )
             else:
-                #not executing - don't waste time converting incompatible sources, just return dummy strings
-                #for the command preview (since the source isn't compatible with OGR, it has no meaning anyway and can't
-                #be run directly in the command line)
-                ogr_data_path = 'path_to_data_file'
-                ogr_layer_name = 'layer_name'
-        elif input_layer.dataProvider().name() == 'ogr':
-            if executing and isinstance(parameters[parameter_name], QgsProcessingFeatureSourceDefinition) and parameters[parameter_name].selectedFeaturesOnly:
+                # not executing - don't waste time converting incompatible sources, just return dummy strings
+                # for the command preview (since the source isn't compatible with OGR, it has no meaning anyway and can't
+                # be run directly in the command line)
+                return GdalConnectionDetails(
+                    connection_string='path_to_data_file',
+                    layer_name='layer_name'
+                )
+        elif input_layer.providerType() == 'ogr':
+            if executing and (isinstance(parameters[parameter_name], QgsProcessingFeatureSourceDefinition) and parameters[parameter_name].selectedFeaturesOnly) \
+                    or input_layer.subsetString():
                 # parameter is a vector layer, with OGR data provider
                 # so extract selection if required
                 ogr_data_path = self.parameterAsCompatibleSourceLayerPath(parameters, parameter_name, context,
@@ -109,18 +119,31 @@ class GdalAlgorithm(QgsProcessingAlgorithm):
                     ogr_layer_name = parts['layerName']
                 else:
                     ogr_layer_name = GdalUtils.ogrLayerName(ogr_data_path)
+                return GdalConnectionDetails(
+                    connection_string=ogr_data_path,
+                    layer_name=ogr_layer_name,
+                    open_options=parts.get('openOptions', None)
+                )
             else:
-                #either not using the selection, or
-                #not executing - don't worry about 'selected features only' handling. It has no meaning
-                #for the command line preview since it has no meaning outside of a QGIS session!
-                ogr_data_path = GdalUtils.ogrConnectionStringAndFormatFromLayer(input_layer)[0]
-                ogr_layer_name = GdalUtils.ogrLayerName(input_layer.dataProvider().dataSourceUri())
-        else:
-            # vector layer, but not OGR - get OGR compatible path
-            # TODO - handle "selected features only" mode!!
-            ogr_data_path = GdalUtils.ogrConnectionStringFromLayer(input_layer)
-            ogr_layer_name = GdalUtils.ogrLayerName(input_layer.dataProvider().dataSourceUri())
-        return ogr_data_path, ogr_layer_name
+                # either not using the selection, or
+                # not executing - don't worry about 'selected features only' handling. It has no meaning
+                # for the command line preview since it has no meaning outside of a QGIS session!
+                connection_details = GdalUtils.gdal_connection_details_from_layer(input_layer)
+                connection_details.layer_name = GdalUtils.ogrLayerName(input_layer.source())
+                return connection_details
+        elif input_layer.providerType().lower() == 'wfs':
+            uri = QgsDataSourceUri(input_layer.source())
+            baseUrl = uri.param('url').split('?')[0]
+            return GdalConnectionDetails(
+                connection_string=f"WFS:{baseUrl}",
+                layer_name=uri.param('typename')
+            )
+
+        # vector layer, but not OGR - get OGR compatible path
+        # TODO - handle "selected features only" mode!!
+        connection_details = GdalUtils.gdal_connection_details_from_layer(input_layer)
+        connection_details.layer_name = GdalUtils.ogrLayerName(input_layer.source())
+        return connection_details
 
     def setOutputValue(self, name, value):
         self.output_values[name] = value
@@ -140,9 +163,10 @@ class GdalAlgorithm(QgsProcessingAlgorithm):
         return results
 
     def commandName(self):
-        parameters = {}
-        for param in self.parameterDefinitions():
-            parameters[param.name()] = "1"
+        parameters = {
+            param.name(): "1"
+            for param in self.parameterDefinitions()
+        }
         context = QgsProcessingContext()
         feedback = QgsProcessingFeedback()
         name = self.getConsoleCommands(parameters, context, feedback, executing=False)[0]
