@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     gdal2xyz.py
@@ -21,16 +19,13 @@ __author__ = 'Alexander Bruy'
 __date__ = 'September 2013'
 __copyright__ = '(C) 2013, Alexander Bruy'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
-
 from qgis.core import (QgsProcessingAlgorithm,
                        QgsProcessingException,
                        QgsProcessingParameterRasterLayer,
                        QgsProcessingParameterBand,
                        QgsProcessingParameterBoolean,
-                       QgsProcessingParameterFileDestination
+                       QgsProcessingParameterFileDestination,
+                       QgsProcessingParameterNumber
                        )
 from processing.algs.gdal.GdalAlgorithm import GdalAlgorithm
 from processing.algs.gdal.GdalUtils import GdalUtils
@@ -38,9 +33,11 @@ from processing.tools.system import isWindows
 
 
 class gdal2xyz(GdalAlgorithm):
-
     INPUT = 'INPUT'
     BAND = 'BAND'
+    SRCNODATA = 'NODATA_INPUT'
+    DSTNODATA = 'NODATA_OUTPUT'
+    SKIPNODATA = 'SKIP_NODATA'
     CSV = 'CSV'
     OUTPUT = 'OUTPUT'
 
@@ -54,6 +51,16 @@ class gdal2xyz(GdalAlgorithm):
                                                      self.tr('Band number'),
                                                      1,
                                                      parentLayerParameterName=self.INPUT))
+
+        self.addParameter(QgsProcessingParameterNumber(self.SRCNODATA,
+                                                       self.tr('Input pixel value to treat as NoData'),
+                                                       optional=True))  # GDAL > 3.6.3
+        self.addParameter(QgsProcessingParameterNumber(self.DSTNODATA,
+                                                       self.tr('Assign specified NoData value to output'),
+                                                       optional=True))  # GDAL > 3.6.3
+        self.addParameter(QgsProcessingParameterBoolean(self.SKIPNODATA,
+                                                        self.tr('Do not output NoData values'),
+                                                        defaultValue=False))  # GDAL > 3.3
         self.addParameter(QgsProcessingParameterBoolean(self.CSV,
                                                         self.tr('Output comma-separated values'),
                                                         defaultValue=False))
@@ -77,28 +84,47 @@ class gdal2xyz(GdalAlgorithm):
         return 'gdal2xyz'
 
     def flags(self):
-        return super().flags() | QgsProcessingAlgorithm.FlagDisplayNameIsLiteral
+        return super().flags() | QgsProcessingAlgorithm.Flag.FlagDisplayNameIsLiteral
 
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
-        arguments = []
-        arguments.append('-band')
-        arguments.append(str(self.parameterAsInt(parameters, self.BAND, context)))
+        arguments = [
+            '-band',
+            str(self.parameterAsInt(parameters, self.BAND, context))
+        ]
 
-        if self.parameterAsBool(parameters, self.CSV, context):
+        if self.SRCNODATA in parameters and parameters[self.SRCNODATA] is not None:
+            if GdalUtils.version() > 3060300:  # src/dstnodata broken <= 3.6.3 https://github.com/OSGeo/gdal/issues/7410
+                srcnodata = self.parameterAsDouble(parameters, self.SRCNODATA, context)
+                arguments.append('-srcnodata')
+                arguments.append(srcnodata)
+            else:
+                raise QgsProcessingException(self.tr('The source nodata option (-srcnodata) is only available on GDAL 3.6.4 or later'))
+
+        if self.DSTNODATA in parameters and parameters[self.DSTNODATA] is not None:
+            if GdalUtils.version() > 3060300:  # src/dstnodata broken <= 3.6.3 https://github.com/OSGeo/gdal/issues/7410
+                dstnodata = self.parameterAsDouble(parameters, self.DSTNODATA, context)
+                arguments.append('-dstnodata')
+                arguments.append(dstnodata)
+            else:
+                raise QgsProcessingException(self.tr('The destination nodata option (-dstnodata) is only available on GDAL 3.6.4 or later'))
+
+        if self.SKIPNODATA in parameters:
+            if GdalUtils.version() >= 3030000:  # skipnodata added at GDAL 3.3
+                if self.parameterAsBoolean(parameters, self.SKIPNODATA, context):
+                    arguments.append('-skipnodata')
+            else:
+                raise QgsProcessingException(self.tr('The skip nodata option (-skipnodata) is only available on GDAL 3.3 or later'))
+
+        if self.parameterAsBoolean(parameters, self.CSV, context):
             arguments.append('-csv')
 
         raster = self.parameterAsRasterLayer(parameters, self.INPUT, context)
         if raster is None:
             raise QgsProcessingException(self.invalidRasterError(parameters, self.INPUT))
 
-        arguments.append(raster.source())
+        input_details = GdalUtils.gdal_connection_details_from_layer(raster)
+
+        arguments.append(input_details.connection_string)
         arguments.append(self.parameterAsFileOutput(parameters, self.OUTPUT, context))
 
-        if isWindows():
-            commands = ["python3", "-m", self.commandName()]
-        else:
-            commands = [self.commandName() + '.py']
-
-        commands.append(GdalUtils.escapeAndJoin(arguments))
-
-        return commands
+        return [self.commandName() + ('.bat' if isWindows() else '.py'), GdalUtils.escapeAndJoin(arguments)]
