@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     ogr2ogr.py
@@ -46,7 +44,7 @@ class ogr2ogr(GdalAlgorithm):
     def initAlgorithm(self, config=None):
         self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
                                                               self.tr('Input layer'),
-                                                              types=[QgsProcessing.TypeVector]))
+                                                              types=[QgsProcessing.SourceType.TypeVector]))
 
         convert_all_layers_param = QgsProcessingParameterBoolean(self.CONVERT_ALL_LAYERS,
                                                                  self.tr('Convert all layers from dataset'), defaultValue=False)
@@ -58,7 +56,7 @@ class ogr2ogr(GdalAlgorithm):
                                                      self.tr('Additional creation options'),
                                                      defaultValue='',
                                                      optional=True)
-        options_param.setFlags(options_param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
+        options_param.setFlags(options_param.flags() | QgsProcessingParameterDefinition.Flag.FlagAdvanced)
         self.addParameter(options_param)
 
         self.addParameter(QgsProcessingParameterVectorDestination(self.OUTPUT,
@@ -80,28 +78,31 @@ class ogr2ogr(GdalAlgorithm):
         return 'ogr2ogr'
 
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
-        ogrLayer, layerName = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
+        input_details = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
         convertAllLayers = self.parameterAsBoolean(parameters, self.CONVERT_ALL_LAYERS, context)
         options = self.parameterAsString(parameters, self.OPTIONS, context)
         outFile = self.parameterAsOutputLayer(parameters, self.OUTPUT, context)
         self.setOutputValue(self.OUTPUT, outFile)
 
-        output, outputFormat = GdalUtils.ogrConnectionStringAndFormat(outFile, context)
+        output_details = GdalUtils.gdal_connection_details_from_uri(outFile, context)
 
-        if outputFormat in ('SQLite', 'GPKG') and os.path.isfile(output):
-            raise QgsProcessingException(self.tr('Output file "{}" already exists.'.format(output)))
+        if output_details.format in ('SQLite', 'GPKG') and os.path.isfile(output_details.connection_string):
+            raise QgsProcessingException(self.tr('Output file "{}" already exists.').format(output_details.connection_string))
 
         arguments = []
-        if outputFormat:
-            arguments.append('-f {}'.format(outputFormat))
+        if output_details.format:
+            arguments.append(f'-f {output_details.format}')
+
+        if input_details.open_options:
+            arguments.extend(input_details.open_options_as_arguments())
 
         if options:
             arguments.append(options)
 
-        arguments.append(output)
-        arguments.append(ogrLayer)
+        arguments.append(output_details.connection_string)
+        arguments.append(input_details.connection_string)
         if not convertAllLayers:
-            arguments.append(layerName)
+            arguments.append(input_details.layer_name)
 
         return ['ogr2ogr', GdalUtils.escapeAndJoin(arguments)]
 
