@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     RangePanel.py
@@ -21,10 +19,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
-
 import os
 import warnings
 
@@ -43,16 +37,15 @@ with warnings.catch_warnings():
 
 
 class RangePanel(BASE, WIDGET):
-
     hasChanged = pyqtSignal()
 
     def __init__(self, param):
-        super(RangePanel, self).__init__(None)
+        super().__init__(None)
         self.setupUi(self)
 
         self.param = param
         # Integer or Double range
-        if self.param.dataType() == QgsProcessingParameterNumber.Integer:
+        if self.param.dataType() == QgsProcessingParameterNumber.Type.Integer:
             self.spnMin.setDecimals(0)
             self.spnMax.setDecimals(0)
 
@@ -77,7 +70,7 @@ class RangePanel(BASE, WIDGET):
             self.hasChanged.emit()
 
     def getValue(self):
-        return '{},{}'.format(self.spnMin.value(), self.spnMax.value())
+        return f'{self.spnMin.value()},{self.spnMax.value()}'
 
     def getValues(self):
         value = self.getValue()
