@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     TestTools.py
@@ -55,6 +53,8 @@ from qgis.core import (QgsApplication,
 from qgis.PyQt.QtCore import QCoreApplication, QMetaObject
 from qgis.PyQt.QtWidgets import QDialog, QVBoxLayout, QTextEdit, QMessageBox
 
+gdal.UseExceptions()
+
 
 def extractSchemaPath(filepath):
     """
@@ -149,7 +149,7 @@ def createTest(text):
 
     alg = QgsApplication.processingRegistry().createAlgorithmById(alg_id)
 
-    definition['name'] = 'Test ({})'.format(alg_id)
+    definition['name'] = f'Test ({alg_id})'
     definition['algorithm'] = alg_id
 
     params = {}
@@ -157,7 +157,7 @@ def createTest(text):
 
     i = 0
     for param in alg.parameterDefinitions():
-        if param.flags() & QgsProcessingParameterDefinition.FlagHidden or param.isDestination():
+        if param.flags() & QgsProcessingParameterDefinition.Flag.FlagHidden or param.isDestination():
             continue
 
         if not param.name() in parameters:
@@ -166,7 +166,7 @@ def createTest(text):
         i += 1
         token = parameters[param.name()]
         # Handle empty parameters that are optionals
-        if param.flags() & QgsProcessingParameterDefinition.FlagOptional and token is None:
+        if param.flags() & QgsProcessingParameterDefinition.Flag.FlagOptional and token is None:
             continue
 
         if isinstance(param, (QgsProcessingParameterVectorLayer, QgsProcessingParameterFeatureSource)):
@@ -195,7 +195,7 @@ def createTest(text):
 
             # Handle datatype detection
             dataType = param.layerType()
-            if dataType in [QgsProcessing.TypeVectorAnyGeometry, QgsProcessing.TypeVectorPoint, QgsProcessing.TypeVectorLine, QgsProcessing.TypeVectorPolygon, QgsProcessing.TypeVector]:
+            if dataType in [QgsProcessing.SourceType.TypeVectorAnyGeometry, QgsProcessing.SourceType.TypeVectorPoint, QgsProcessing.SourceType.TypeVectorLine, QgsProcessing.SourceType.TypeVectorPolygon, QgsProcessing.SourceType.TypeVector]:
                 dataType = 'vector'
             else:
                 dataType = 'raster'
@@ -230,7 +230,7 @@ def createTest(text):
         elif isinstance(param, QgsProcessingParameterBoolean):
             params[param.name()] = token
         elif isinstance(param, (QgsProcessingParameterNumber, QgsProcessingParameterDistance)):
-            if param.dataType() == QgsProcessingParameterNumber.Integer:
+            if param.dataType() == QgsProcessingParameterNumber.Type.Integer:
                 params[param.name()] = int(token)
             else:
                 params[param.name()] = float(token)
@@ -250,7 +250,7 @@ def createTest(text):
 
     definition['params'] = params
 
-    for i, out in enumerate([out for out in alg.destinationParameterDefinitions() if not out.flags() & QgsProcessingParameterDefinition.FlagHidden]):
+    for i, out in enumerate([out for out in alg.destinationParameterDefinitions() if not out.flags() & QgsProcessingParameterDefinition.Flag.FlagHidden]):
         if not out.name() in parameters:
             continue
 
@@ -266,8 +266,9 @@ def createTest(text):
                                        'files'))
                 return
 
-            dataset = gdal.Open(token, GA_ReadOnly)
-            if dataset is None:
+            try:
+                dataset = gdal.Open(token, GA_ReadOnly)
+            except Exception:
                 QMessageBox.warning(None,
                                     tr('Error'),
                                     tr('Seems some outputs are temporary '
@@ -302,7 +303,7 @@ def createTest(text):
 
     definition['results'] = results
     dlg = ShowTestDialog(yaml.dump([definition], default_flow_style=False))
-    dlg.exec_()
+    dlg.exec()
 
 
 def tr(string):
